"""
Python module generated from Java source file org.bukkit.event.entity.EntityRemoveEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import Entity
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityRemoveEvent(EntityEvent):
    """
    Called when an Entity is removed.
    
    This event should only be used for monitoring. The result
    of modifying the entity during or after this event is unspecified.
    This event is not called for a org.bukkit.entity.Player.
    """

    def __init__(self, what: "Entity", cause: "Cause"):
        ...


    def getCause(self) -> "Cause":
        """
        Gets the cause why the entity got removed.

        Returns
        - the cause why the entity got removed
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class Cause(Enum):
        """
        Represents various ways an entity gets removed.
        """

        DEATH = 0
        """
        When an entity dies.
        """
        DESPAWN = 1
        """
        When an entity does despawn. This includes mobs which are too far away,
        items or arrows which lay to long on the ground or area effect cloud.
        """
        DROP = 2
        """
        When an entity gets removed because it drops as an item.
        For example, trident or falling sand.
        
        **Note:** Depending on other factors, such as gamerules, no item will actually drop,
        the cause, however, will still be drop.
        """
        ENTER_BLOCK = 3
        """
        When an entity gets removed because it enters a block.
        For example, bees or silverfish.
        """
        EXPLODE = 4
        """
        When an entity gets removed because it exploded.
        For example, creepers, tnt or firework.
        """
        HIT = 5
        """
        When an entity gets removed because it hit something. This mainly applies to projectiles.
        """
        MERGE = 6
        """
        When an entity gets removed because it merges with another one.
        For example, items or xp.
        """
        OUT_OF_WORLD = 7
        """
        When an entity gets removed because it is too far below the world.
        This only applies to entities which get removed immediately,
        some entities get damage instead.
        """
        PICKUP = 8
        """
        When an entity gets removed because it got pickup.
        For example, items, arrows, xp or parrots which get on a player shoulder.
        """
        PLAYER_QUIT = 9
        """
        When an entity gets removed with a player because the player quits the game.
        For example, a boat which gets removed with the player when he quits.
        """
        PLUGIN = 10
        """
        When a plugin manually removes an entity.
        """
        TRANSFORMATION = 11
        """
        When an entity gets removed because it transforms into another one.
        """
        UNLOAD = 12
        """
        When the chunk an entity is in gets unloaded.
        """



"""
Python module generated from Java source file com.google.gson.internal.sql.SqlTimeTypeAdapter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonSyntaxException
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal.sql import *
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.text import DateFormat
from java.text import ParseException
from java.text import SimpleDateFormat
from java.util import Date
from java.util import TimeZone
from typing import Any, Callable, Iterable, Tuple


class SqlTimeTypeAdapter(TypeAdapter):
    """
    Adapter for java.sql.Time. Although this class appears stateless, it is not. DateFormat captures
    its time zone and locale when it is created, which gives this class state. DateFormat isn't
    thread safe either, so this class has to synchronize its read and write methods.
    """

    def read(self, in: "JsonReader") -> "Time":
        ...


    def write(self, out: "JsonWriter", value: "Time") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.configuration.MemoryConfigurationOptions

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.configuration import *
from typing import Any, Callable, Iterable, Tuple


class MemoryConfigurationOptions(ConfigurationOptions):
    """
    Various settings for controlling the input and output of a MemoryConfiguration
    """

    def configuration(self) -> "MemoryConfiguration":
        ...


    def copyDefaults(self, value: bool) -> "MemoryConfigurationOptions":
        ...


    def pathSeparator(self, value: str) -> "MemoryConfigurationOptions":
        ...



"""
Python module generated from Java source file java.util.function.LongUnaryOperator

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class LongUnaryOperator:
    """
    Represents an operation on a single `long`-valued operand that produces
    a `long`-valued result.  This is the primitive type specialization of
    UnaryOperator for `long`.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .applyAsLong(long).

    See
    - UnaryOperator

    Since
    - 1.8
    """

    def applyAsLong(self, operand: int) -> int:
        """
        Applies this operator to the given operand.

        Arguments
        - operand: the operand

        Returns
        - the operator result
        """
        ...


    def compose(self, before: "LongUnaryOperator") -> "LongUnaryOperator":
        """
        Returns a composed operator that first applies the `before`
        operator to its input, and then applies this operator to the result.
        If evaluation of either operator throws an exception, it is relayed to
        the caller of the composed operator.

        Arguments
        - before: the operator to apply before this operator is applied

        Returns
        - a composed operator that first applies the `before`
        operator and then applies this operator

        Raises
        - NullPointerException: if before is null

        See
        - .andThen(LongUnaryOperator)
        """
        ...


    def andThen(self, after: "LongUnaryOperator") -> "LongUnaryOperator":
        """
        Returns a composed operator that first applies this operator to
        its input, and then applies the `after` operator to the result.
        If evaluation of either operator throws an exception, it is relayed to
        the caller of the composed operator.

        Arguments
        - after: the operator to apply after this operator is applied

        Returns
        - a composed operator that first applies this operator and then
        applies the `after` operator

        Raises
        - NullPointerException: if after is null

        See
        - .compose(LongUnaryOperator)
        """
        ...


    @staticmethod
    def identity() -> "LongUnaryOperator":
        """
        Returns a unary operator that always returns its input argument.

        Returns
        - a unary operator that always returns its input argument
        """
        ...



"""
Python module generated from Java source file java.security.AccessControlException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.security import *
from typing import Any, Callable, Iterable, Tuple


class AccessControlException(SecurityException):

    def __init__(self, s: str):
        """
        Constructs an `AccessControlException` with the
        specified, detailed message.

        Arguments
        - s: the detail message.
        """
        ...


    def __init__(self, s: str, p: "Permission"):
        """
        Constructs an `AccessControlException` with the
        specified, detailed message, and the requested permission that caused
        the exception.

        Arguments
        - s: the detail message.
        - p: the permission that caused the exception.
        """
        ...


    def getPermission(self) -> "Permission":
        """
        Gets the Permission object associated with this exception, or
        null if there was no corresponding Permission object.

        Returns
        - the Permission object.
        """
        ...



"""
Python module generated from Java source file java.io.RandomAccessFile

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from jdk.internal.access import JavaIORandomAccessFileAccess
from jdk.internal.access import SharedSecrets
from sun.nio.ch import FileChannelImpl
from typing import Any, Callable, Iterable, Tuple


class RandomAccessFile(DataOutput, DataInput, Closeable):

    def __init__(self, name: str, mode: str):
        """
        Creates a random access file stream to read from, and optionally
        to write to, a file with the specified name. A new
        FileDescriptor object is created to represent the
        connection to the file.
        
         The `mode` argument specifies the access mode with which the
        file is to be opened.  The permitted values and their meanings are as
        specified for the <a
        href="#mode">`RandomAccessFile(File,String)`</a> constructor.
        
        
        If there is a security manager, its `checkRead` method
        is called with the `name` argument
        as its argument to see if read access to the file is allowed.
        If the mode allows writing, the security manager's
        `checkWrite` method
        is also called with the `name` argument
        as its argument to see if write access to the file is allowed.

        Arguments
        - name: the system-dependent filename
        - mode: the access <a href="#mode">mode</a>

        Raises
        - IllegalArgumentException: if the mode argument is not equal
                    to one of `"r"`, `"rw"`, `"rws"`, or
                    `"rwd"`
        - FileNotFoundException: if the mode is `"r"` but the given string does not
                    denote an existing regular file, or if the mode begins with
                    `"rw"` but the given string does not denote an
                    existing, writable regular file and a new regular file of
                    that name cannot be created, or if some other error occurs
                    while opening or creating the file
        - SecurityException: if a security manager exists and its
                    `checkRead` method denies read access to the file
                    or the mode is `"rw"` and the security manager's
                    `checkWrite` method denies write access to the file

        See
        - java.lang.SecurityManager.checkWrite(java.lang.String)

        Unknown Tags
        - 1.4
        """
        ...


    def __init__(self, file: "File", mode: str):
        """
        Creates a random access file stream to read from, and optionally to
        write to, the file specified by the File argument.  A new FileDescriptor object is created to represent this file connection.
        
        The <a id="mode">`mode`</a> argument specifies the access mode
        in which the file is to be opened.  The permitted values and their
        meanings are:
        
        <table class="striped">
        <caption style="display:none">Access mode permitted values and meanings</caption>
        <thead>
        <tr><th scope="col" style="text-align:left">Value</th><th scope="col" style="text-align:left">Meaning</th></tr>
        </thead>
        <tbody>
        <tr><th scope="row" style="vertical-align:top">`"r"`</th>
            <td> Open for reading only. Invoking any of the `write`
            methods of the resulting object will cause an
            java.io.IOException to be thrown.</td></tr>
        <tr><th scope="row" style="vertical-align:top">`"rw"`</th>
            <td> Open for reading and writing.  If the file does not already
            exist then an attempt will be made to create it.</td></tr>
        <tr><th scope="row" style="vertical-align:top">`"rws"`</th>
            <td> Open for reading and writing, as with `"rw"`, and also
            require that every update to the file's content or metadata be
            written synchronously to the underlying storage device.</td></tr>
        <tr><th scope="row" style="vertical-align:top">`"rwd"`</th>
            <td> Open for reading and writing, as with `"rw"`, and also
            require that every update to the file's content be written
            synchronously to the underlying storage device.</td></tr>
        </tbody>
        </table>
        
        The `"rws"` and `"rwd"` modes work much like the java.nio.channels.FileChannel.force(boolean) force(boolean) method of
        the java.nio.channels.FileChannel class, passing arguments of
        `True` and `False`, respectively, except that they always
        apply to every I/O operation and are therefore often more efficient.  If
        the file resides on a local storage device then when an invocation of a
        method of this class returns it is guaranteed that all changes made to
        the file by that invocation will have been written to that device.  This
        is useful for ensuring that critical information is not lost in the
        event of a system crash.  If the file does not reside on a local device
        then no such guarantee is made.
        
        The `"rwd"` mode can be used to reduce the number of I/O
        operations performed.  Using `"rwd"` only requires updates to the
        file's content to be written to storage; using `"rws"` requires
        updates to both the file's content and its metadata to be written, which
        generally requires at least one more low-level I/O operation.
        
        If there is a security manager, its `checkRead` method is
        called with the pathname of the `file` argument as its
        argument to see if read access to the file is allowed.  If the mode
        allows writing, the security manager's `checkWrite` method is
        also called with the path argument to see if write access to the file is
        allowed.

        Arguments
        - file: the file object
        - mode: the access mode, as described
                           <a href="#mode">above</a>

        Raises
        - IllegalArgumentException: if the mode argument is not equal
                    to one of `"r"`, `"rw"`, `"rws"`, or
                    `"rwd"`
        - FileNotFoundException: if the mode is `"r"` but the given file object does
                    not denote an existing regular file, or if the mode begins
                    with `"rw"` but the given file object does not denote
                    an existing, writable regular file and a new regular file of
                    that name cannot be created, or if some other error occurs
                    while opening or creating the file
        - SecurityException: if a security manager exists and its
                    `checkRead` method denies read access to the file
                    or the mode is `"rw"` and the security manager's
                    `checkWrite` method denies write access to the file

        See
        - java.nio.channels.FileChannel.force(boolean)

        Unknown Tags
        - 1.4
        """
        ...


    def getFD(self) -> "FileDescriptor":
        """
        Returns the opaque file descriptor object associated with this
        stream.

        Returns
        - the file descriptor object associated with this stream.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FileDescriptor
        """
        ...


    def getChannel(self) -> "FileChannel":
        """
        Returns the unique java.nio.channels.FileChannel FileChannel
        object associated with this file.
        
         The java.nio.channels.FileChannel.position()
        position of the returned channel will always be equal to
        this object's file-pointer offset as returned by the .getFilePointer getFilePointer method.  Changing this object's
        file-pointer offset, whether explicitly or by reading or writing bytes,
        will change the position of the channel, and vice versa.  Changing the
        file's length via this object will change the length seen via the file
        channel, and vice versa.

        Returns
        - the file channel associated with this file

        Since
        - 1.4
        """
        ...


    def read(self) -> int:
        """
        Reads a byte of data from this file. The byte is returned as an
        integer in the range 0 to 255 (`0x00-0x0ff`). This
        method blocks if no input is yet available.
        
        Although `RandomAccessFile` is not a subclass of
        `InputStream`, this method behaves in exactly the same
        way as the InputStream.read() method of
        `InputStream`.

        Returns
        - the next byte of data, or `-1` if the end of the
                    file has been reached.

        Raises
        - IOException: if an I/O error occurs. Not thrown if
                                 end-of-file has been reached.
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads up to `len` bytes of data from this file into an
        array of bytes. This method blocks until at least one byte of input
        is available.
        
        Although `RandomAccessFile` is not a subclass of
        `InputStream`, this method behaves in exactly the
        same way as the InputStream.read(byte[], int, int) method of
        `InputStream`.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset in array `b`
                          at which the data is written.
        - len: the maximum number of bytes read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    the file has been reached.

        Raises
        - IOException: If the first byte cannot be read for any reason
                    other than end of file, or if the random access file has been closed,
                    or if some other I/O error occurs.
        - NullPointerException: If `b` is `null`.
        - IndexOutOfBoundsException: If `off` is negative,
                    `len` is negative, or `len` is greater than
                    `b.length - off`
        """
        ...


    def read(self, b: list[int]) -> int:
        """
        Reads up to `b.length` bytes of data from this file
        into an array of bytes. This method blocks until at least one byte
        of input is available.
        
        Although `RandomAccessFile` is not a subclass of
        `InputStream`, this method behaves in exactly the
        same way as the InputStream.read(byte[]) method of
        `InputStream`.

        Arguments
        - b: the buffer into which the data is read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    this file has been reached.

        Raises
        - IOException: If the first byte cannot be read for any reason
                    other than end of file, or if the random access file has been closed,
                    or if some other I/O error occurs.
        - NullPointerException: If `b` is `null`.
        """
        ...


    def readFully(self, b: list[int]) -> None:
        """
        Reads `b.length` bytes from this file into the byte
        array, starting at the current file pointer. This method reads
        repeatedly from the file until the requested number of bytes are
        read. This method blocks until the requested number of bytes are
        read, the end of the stream is detected, or an exception is thrown.

        Arguments
        - b: the buffer into which the data is read.

        Raises
        - NullPointerException: if `b` is `null`.
        - EOFException: if this file reaches the end before reading
                     all the bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def readFully(self, b: list[int], off: int, len: int) -> None:
        """
        Reads exactly `len` bytes from this file into the byte
        array, starting at the current file pointer. This method reads
        repeatedly from the file until the requested number of bytes are
        read. This method blocks until the requested number of bytes are
        read, the end of the stream is detected, or an exception is thrown.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset into the data array `b`.
        - len: the number of bytes to read.

        Raises
        - NullPointerException: if `b` is `null`.
        - IndexOutOfBoundsException: if `off` is negative,
                       `len` is negative, or `len` is greater than
                       `b.length - off`.
        - EOFException: if this file reaches the end before reading
                       all the bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def skipBytes(self, n: int) -> int:
        """
        Attempts to skip over `n` bytes of input discarding the
        skipped bytes.
        
        
        This method may skip over some smaller number of bytes, possibly zero.
        This may result from any of a number of conditions; reaching end of
        file before `n` bytes have been skipped is only one
        possibility. This method never throws an `EOFException`.
        The actual number of bytes skipped is returned.  If `n`
        is negative, no bytes are skipped.

        Arguments
        - n: the number of bytes to be skipped.

        Returns
        - the actual number of bytes skipped.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def write(self, b: int) -> None:
        """
        Writes the specified byte to this file. The write starts at
        the current file pointer.

        Arguments
        - b: the `byte` to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def write(self, b: list[int]) -> None:
        """
        Writes `b.length` bytes from the specified byte array
        to this file, starting at the current file pointer.

        Arguments
        - b: the data.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        """
        Writes `len` bytes from the specified byte array
        starting at offset `off` to this file.

        Arguments
        - b: the data.
        - off: the start offset in the data.
        - len: the number of bytes to write.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def getFilePointer(self) -> int:
        """
        Returns the current offset in this file.

        Returns
        - the offset from the beginning of the file, in bytes,
                    at which the next read or write occurs.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def seek(self, pos: int) -> None:
        """
        Sets the file-pointer offset, measured from the beginning of this
        file, at which the next read or write occurs.  The offset may be
        set beyond the end of the file. Setting the offset beyond the end
        of the file does not change the file length.  The file length will
        change only by writing after the offset has been set beyond the end
        of the file.

        Arguments
        - pos: the offset position, measured in bytes from the
                          beginning of the file, at which to set the file
                          pointer.

        Raises
        - IOException: if `pos` is less than
                                 `0` or if an I/O error occurs.
        """
        ...


    def length(self) -> int:
        """
        Returns the length of this file.

        Returns
        - the length of this file, measured in bytes.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def setLength(self, newLength: int) -> None:
        """
        Sets the length of this file.
        
         If the present length of the file as returned by the
        `length` method is greater than the `newLength`
        argument then the file will be truncated.  In this case, if the file
        offset as returned by the `getFilePointer` method is greater
        than `newLength` then after this method returns the offset
        will be equal to `newLength`.
        
         If the present length of the file as returned by the
        `length` method is smaller than the `newLength`
        argument then the file will be extended.  In this case, the contents of
        the extended portion of the file are not defined.

        Arguments
        - newLength: The desired length of the file

        Raises
        - IOException: If an I/O error occurs

        Since
        - 1.2
        """
        ...


    def close(self) -> None:
        """
        Closes this random access file stream and releases any system
        resources associated with the stream. A closed random access
        file cannot perform input or output operations and cannot be
        reopened.
        
         If this file has an associated channel then the channel is closed
        as well.

        Raises
        - IOException: if an I/O error occurs.

        Unknown Tags
        - 1.4
        """
        ...


    def readBoolean(self) -> bool:
        """
        Reads a `boolean` from this file. This method reads a
        single byte from the file, starting at the current file pointer.
        A value of `0` represents
        `False`. Any other value represents `True`.
        This method blocks until the byte is read, the end of the stream
        is detected, or an exception is thrown.

        Returns
        - the `boolean` value read.

        Raises
        - EOFException: if this file has reached the end.
        - IOException: if an I/O error occurs.
        """
        ...


    def readByte(self) -> int:
        """
        Reads a signed eight-bit value from this file. This method reads a
        byte from the file, starting from the current file pointer.
        If the byte read is `b`, where
        `0 <= b <= 255`,
        then the result is:
        <blockquote>```
            (byte)(b)
        ```</blockquote>
        
        This method blocks until the byte is read, the end of the stream
        is detected, or an exception is thrown.

        Returns
        - the next byte of this file as a signed eight-bit
                    `byte`.

        Raises
        - EOFException: if this file has reached the end.
        - IOException: if an I/O error occurs.
        """
        ...


    def readUnsignedByte(self) -> int:
        """
        Reads an unsigned eight-bit number from this file. This method reads
        a byte from this file, starting at the current file pointer,
        and returns that byte.
        
        This method blocks until the byte is read, the end of the stream
        is detected, or an exception is thrown.

        Returns
        - the next byte of this file, interpreted as an unsigned
                    eight-bit number.

        Raises
        - EOFException: if this file has reached the end.
        - IOException: if an I/O error occurs.
        """
        ...


    def readShort(self) -> int:
        """
        Reads a signed 16-bit number from this file. The method reads two
        bytes from this file, starting at the current file pointer.
        If the two bytes read, in order, are
        `b1` and `b2`, where each of the two values is
        between `0` and `255`, inclusive, then the
        result is equal to:
        <blockquote>```
            (short)((b1 &lt;&lt; 8) | b2)
        ```</blockquote>
        
        This method blocks until the two bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next two bytes of this file, interpreted as a signed
                    16-bit number.

        Raises
        - EOFException: if this file reaches the end before reading
                      two bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def readUnsignedShort(self) -> int:
        """
        Reads an unsigned 16-bit number from this file. This method reads
        two bytes from the file, starting at the current file pointer.
        If the bytes read, in order, are
        `b1` and `b2`, where
        `0 <= b1, b2 <= 255`,
        then the result is equal to:
        <blockquote>```
            (b1 &lt;&lt; 8) | b2
        ```</blockquote>
        
        This method blocks until the two bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next two bytes of this file, interpreted as an unsigned
                    16-bit integer.

        Raises
        - EOFException: if this file reaches the end before reading
                      two bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def readChar(self) -> str:
        """
        Reads a character from this file. This method reads two
        bytes from the file, starting at the current file pointer.
        If the bytes read, in order, are
        `b1` and `b2`, where
        `0 <= b1, b2 <= 255`,
        then the result is equal to:
        <blockquote>```
            (char)((b1 &lt;&lt; 8) | b2)
        ```</blockquote>
        
        This method blocks until the two bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next two bytes of this file, interpreted as a
                         `char`.

        Raises
        - EOFException: if this file reaches the end before reading
                      two bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def readInt(self) -> int:
        """
        Reads a signed 32-bit integer from this file. This method reads 4
        bytes from the file, starting at the current file pointer.
        If the bytes read, in order, are `b1`,
        `b2`, `b3`, and `b4`, where
        `0 <= b1, b2, b3, b4 <= 255`,
        then the result is equal to:
        <blockquote>```
            (b1 &lt;&lt; 24) | (b2 &lt;&lt; 16) + (b3 &lt;&lt; 8) + b4
        ```</blockquote>
        
        This method blocks until the four bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next four bytes of this file, interpreted as an
                    `int`.

        Raises
        - EOFException: if this file reaches the end before reading
                      four bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def readLong(self) -> int:
        """
        Reads a signed 64-bit integer from this file. This method reads eight
        bytes from the file, starting at the current file pointer.
        If the bytes read, in order, are
        `b1`, `b2`, `b3`,
        `b4`, `b5`, `b6`,
        `b7`, and `b8,` where:
        <blockquote>```
            0 &lt;= b1, b2, b3, b4, b5, b6, b7, b8 &lt;=255,
        ```</blockquote>
        
        then the result is equal to:
        <blockquote>```
            ((long)b1 &lt;&lt; 56) + ((long)b2 &lt;&lt; 48)
            + ((long)b3 &lt;&lt; 40) + ((long)b4 &lt;&lt; 32)
            + ((long)b5 &lt;&lt; 24) + ((long)b6 &lt;&lt; 16)
            + ((long)b7 &lt;&lt; 8) + b8
        ```</blockquote>
        
        This method blocks until the eight bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next eight bytes of this file, interpreted as a
                    `long`.

        Raises
        - EOFException: if this file reaches the end before reading
                      eight bytes.
        - IOException: if an I/O error occurs.
        """
        ...


    def readFloat(self) -> float:
        """
        Reads a `float` from this file. This method reads an
        `int` value, starting at the current file pointer,
        as if by the `readInt` method
        and then converts that `int` to a `float`
        using the `intBitsToFloat` method in class
        `Float`.
        
        This method blocks until the four bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next four bytes of this file, interpreted as a
                    `float`.

        Raises
        - EOFException: if this file reaches the end before reading
                    four bytes.
        - IOException: if an I/O error occurs.

        See
        - java.lang.Float.intBitsToFloat(int)
        """
        ...


    def readDouble(self) -> float:
        """
        Reads a `double` from this file. This method reads a
        `long` value, starting at the current file pointer,
        as if by the `readLong` method
        and then converts that `long` to a `double`
        using the `longBitsToDouble` method in
        class `Double`.
        
        This method blocks until the eight bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - the next eight bytes of this file, interpreted as a
                    `double`.

        Raises
        - EOFException: if this file reaches the end before reading
                    eight bytes.
        - IOException: if an I/O error occurs.

        See
        - java.lang.Double.longBitsToDouble(long)
        """
        ...


    def readLine(self) -> str:
        ...


    def readUTF(self) -> str:
        """
        Reads in a string from this file. The string has been encoded
        using a
        <a href="DataInput.html#modified-utf-8">modified UTF-8</a>
        format.
        
        The first two bytes are read, starting from the current file
        pointer, as if by
        `readUnsignedShort`. This value gives the number of
        following bytes that are in the encoded string, not
        the length of the resulting string. The following bytes are then
        interpreted as bytes encoding characters in the modified UTF-8 format
        and are converted into characters.
        
        This method blocks until all the bytes are read, the end of the
        stream is detected, or an exception is thrown.

        Returns
        - a Unicode string.

        Raises
        - EOFException: if this file reaches the end before
                      reading all the bytes.
        - IOException: if an I/O error occurs.
        - UTFDataFormatException: if the bytes do not represent
                      valid modified UTF-8 encoding of a Unicode string.

        See
        - java.io.RandomAccessFile.readUnsignedShort()
        """
        ...


    def writeBoolean(self, v: bool) -> None:
        """
        Writes a `boolean` to the file as a one-byte value. The
        value `True` is written out as the value
        `(byte)1`; the value `False` is written out
        as the value `(byte)0`. The write starts at
        the current position of the file pointer.

        Arguments
        - v: a `boolean` value to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeByte(self, v: int) -> None:
        """
        Writes a `byte` to the file as a one-byte value. The
        write starts at the current position of the file pointer.

        Arguments
        - v: a `byte` value to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeShort(self, v: int) -> None:
        """
        Writes a `short` to the file as two bytes, high byte first.
        The write starts at the current position of the file pointer.

        Arguments
        - v: a `short` to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeChar(self, v: int) -> None:
        """
        Writes a `char` to the file as a two-byte value, high
        byte first. The write starts at the current position of the
        file pointer.

        Arguments
        - v: a `char` value to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeInt(self, v: int) -> None:
        """
        Writes an `int` to the file as four bytes, high byte first.
        The write starts at the current position of the file pointer.

        Arguments
        - v: an `int` to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeLong(self, v: int) -> None:
        """
        Writes a `long` to the file as eight bytes, high byte first.
        The write starts at the current position of the file pointer.

        Arguments
        - v: a `long` to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeFloat(self, v: float) -> None:
        """
        Converts the float argument to an `int` using the
        `floatToIntBits` method in class `Float`,
        and then writes that `int` value to the file as a
        four-byte quantity, high byte first. The write starts at the
        current position of the file pointer.

        Arguments
        - v: a `float` value to be written.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.lang.Float.floatToIntBits(float)
        """
        ...


    def writeDouble(self, v: float) -> None:
        """
        Converts the double argument to a `long` using the
        `doubleToLongBits` method in class `Double`,
        and then writes that `long` value to the file as an
        eight-byte quantity, high byte first. The write starts at the current
        position of the file pointer.

        Arguments
        - v: a `double` value to be written.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.lang.Double.doubleToLongBits(double)
        """
        ...


    def writeBytes(self, s: str) -> None:
        """
        Writes the string to the file as a sequence of bytes. Each
        character in the string is written out, in sequence, by discarding
        its high eight bits. The write starts at the current position of
        the file pointer.

        Arguments
        - s: a string of bytes to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def writeChars(self, s: str) -> None:
        """
        Writes a string to the file as a sequence of characters. Each
        character is written to the data output stream as if by the
        `writeChar` method. The write starts at the current
        position of the file pointer.

        Arguments
        - s: a `String` value to be written.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.RandomAccessFile.writeChar(int)
        """
        ...


    def writeUTF(self, str: str) -> None:
        """
        Writes a string to the file using
        <a href="DataInput.html#modified-utf-8">modified UTF-8</a>
        encoding in a machine-independent manner.
        
        First, two bytes are written to the file, starting at the
        current file pointer, as if by the
        `writeShort` method giving the number of bytes to
        follow. This value is the number of bytes actually written out,
        not the length of the string. Following the length, each character
        of the string is output, in sequence, using the modified UTF-8 encoding
        for each character.

        Arguments
        - str: a string to be written.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...



"""
Python module generated from Java source file org.bukkit.util.CachedServerIcon

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Server
from org.bukkit.event.server import ServerListPingEvent
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class CachedServerIcon:
    """
    This is a cached version of a server-icon. It's internal representation
    and implementation is undefined.

    See
    - ServerListPingEvent.setServerIcon(CachedServerIcon)
    """





"""
Python module generated from Java source file com.google.common.collect.TopKSelector

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.common.math import IntMath
from java.math import RoundingMode
from java.util import Arrays
from java.util import Collections
from java.util import Comparator
from java.util import Iterator
from java.util.stream import Stream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class TopKSelector:
    """
    An accumulator that selects the "top" `k` elements added to it, relative to a provided
    comparator. "Top" can mean the greatest or the lowest elements, specified in the factory used to
    create the `TopKSelector` instance.
    
    If your input data is available as a Stream, prefer passing Comparators.least(int) to Stream.collect(java.util.stream.Collector). If it is available
    as an Iterable or Iterator, prefer Ordering.leastOf(Iterable, int).
    
    This uses the same efficient implementation as Ordering.leastOf(Iterable, int),
    offering expected O(n + k log k) performance (worst case O(n log k)) for n calls to .offer and a call to .topK, with O(k) memory. In comparison, quickselect has the same
    asymptotics but requires O(n) memory, and a `PriorityQueue` implementation takes O(n log
    k). In benchmarks, this implementation performs at least as well as either implementation, and
    degrades more gracefully for worst-case input.
    
    The implementation does not necessarily use a *stable* sorting algorithm; when multiple
    equivalent elements are added to it, it is undefined which will come first in the output.

    Author(s)
    - Louis Wasserman
    """

    @staticmethod
    def least(k: int) -> "TopKSelector"["T"]:
        """
        Returns a `TopKSelector` that collects the lowest `k` elements added to it,
        relative to the natural ordering of the elements, and returns them via .topK in
        ascending order.

        Raises
        - IllegalArgumentException: if `k < 0` or `k > Integer.MAX_VALUE / 2`
        """
        ...


    @staticmethod
    def least(k: int, comparator: "Comparator"["T"]) -> "TopKSelector"["T"]:
        """
        Returns a `TopKSelector` that collects the lowest `k` elements added to it,
        relative to the specified comparator, and returns them via .topK in ascending order.

        Raises
        - IllegalArgumentException: if `k < 0` or `k > Integer.MAX_VALUE / 2`
        """
        ...


    @staticmethod
    def greatest(k: int) -> "TopKSelector"["T"]:
        """
        Returns a `TopKSelector` that collects the greatest `k` elements added to it,
        relative to the natural ordering of the elements, and returns them via .topK in
        descending order.

        Raises
        - IllegalArgumentException: if `k < 0` or `k > Integer.MAX_VALUE / 2`
        """
        ...


    @staticmethod
    def greatest(k: int, comparator: "Comparator"["T"]) -> "TopKSelector"["T"]:
        """
        Returns a `TopKSelector` that collects the greatest `k` elements added to it,
        relative to the specified comparator, and returns them via .topK in descending order.

        Raises
        - IllegalArgumentException: if `k < 0` or `k > Integer.MAX_VALUE / 2`
        """
        ...


    def offer(self, elem: "T") -> None:
        """
        Adds `elem` as a candidate for the top `k` elements. This operation takes amortized
        O(1) time.
        """
        ...


    def offerAll(self, elements: Iterable["T"]) -> None:
        """
        Adds each member of `elements` as a candidate for the top `k` elements. This
        operation takes amortized linear time in the length of `elements`.
        
        If all input data to this `TopKSelector` is in a single `Iterable`, prefer
        Ordering.leastOf(Iterable, int), which provides a simpler API for that use case.
        """
        ...


    def offerAll(self, elements: Iterator["T"]) -> None:
        """
        Adds each member of `elements` as a candidate for the top `k` elements. This
        operation takes amortized linear time in the length of `elements`. The iterator is
        consumed after this operation completes.
        
        If all input data to this `TopKSelector` is in a single `Iterator`, prefer
        Ordering.leastOf(Iterator, int), which provides a simpler API for that use case.
        """
        ...


    def topK(self) -> list["T"]:
        """
        Returns the top `k` elements offered to this `TopKSelector`, or all elements if
        fewer than `k` have been offered, in the order specified by the factory used to create
        this `TopKSelector`.
        
        The returned list is an unmodifiable copy and will not be affected by further changes to
        this `TopKSelector`. This method returns in O(k log k) time.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerArmorStandManipulateEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import ArmorStand
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerArmorStandManipulateEvent(PlayerInteractEntityEvent):
    """
    Called when a player interacts with an armor stand and will either swap, retrieve or
    place an item.
    """

    def __init__(self, who: "Player", clickedEntity: "ArmorStand", playerItem: "ItemStack", armorStandItem: "ItemStack", slot: "EquipmentSlot", hand: "EquipmentSlot"):
        ...


    def __init__(self, who: "Player", clickedEntity: "ArmorStand", playerItem: "ItemStack", armorStandItem: "ItemStack", slot: "EquipmentSlot"):
        ...


    def getPlayerItem(self) -> "ItemStack":
        """
        Returns the item held by the player.
        
        If this item is empty and the armor stand item is also empty, there will be no
        transaction between the player and the armor stand. If the player's item is empty
        but the armor stand item is not, the player's item will be placed on the armor
        stand. If both items are not empty, the items will be swapped.
        
        In the case that this event is cancelled, the original items will remain the same.

        Returns
        - the item held by the player.
        """
        ...


    def getArmorStandItem(self) -> "ItemStack":
        """
        Returns the item held by the armor stand.
        
        If this item is empty and the player's item is also empty, there will be no
        transaction between the player and the armor stand. If the player's item is empty
        but the armor stand item is not, then the player will obtain the armor stand item.
        In the case that the player's item is not empty but the armor stand item is empty,
        the player's item will be placed on the armor stand. If both items are not empty,
        the items will be swapped.
        
        In the case that the event is cancelled the original items will remain the same.

        Returns
        - the item held by the armor stand.
        """
        ...


    def getSlot(self) -> "EquipmentSlot":
        """
        Returns the raw item slot of the armor stand in this event.

        Returns
        - the index of the item obtained or placed of the armor stand.
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        
        
        Note that this is not the hand of the armor stand that was changed, but rather
        the hand used by the player to swap items with the armor stand.
        """
        ...


    def getRightClicked(self) -> "ArmorStand":
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityKnockbackEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from org.bukkit.attribute import Attribute
from org.bukkit.enchantments import Enchantment
from org.bukkit.entity import LivingEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class EntityKnockbackEvent(EntityEvent, Cancellable):
    """
    Called when a living entity receives knockback.
    """

    def __init__(self, entity: "LivingEntity", cause: "KnockbackCause", force: float, rawKnockback: "Vector", knockback: "Vector"):
        ...


    def getEntity(self) -> "LivingEntity":
        ...


    def getCause(self) -> "KnockbackCause":
        """
        Gets the cause of the knockback.

        Returns
        - the cause of the knockback
        """
        ...


    def getForce(self) -> float:
        """
        Gets the raw force of the knockback. 
        This value is based on factors such as the Enchantment.KNOCKBACK
        level of an attacker and the
        Attribute.KNOCKBACK_RESISTANCE of the entity.

        Returns
        - the knockback force
        """
        ...


    def getKnockback(self) -> "Vector":
        """
        Gets the raw knockback force that will be applied to the entity. 
        This value is read-only, changes made to it **will not** have any
        effect on the final knockback received.

        Returns
        - the raw knockback

        See
        - .getFinalKnockback()
        """
        ...


    def getFinalKnockback(self) -> "Vector":
        """
        Gets the force that will be applied to the entity. 
        In contrast to EntityKnockbackEvent.getKnockback() this value is
        affected by the entities current velocity and whether they are touching
        the ground.
        
        **Note:** this method returns a copy, changes must be applied with
        .setFinalKnockback(Vector).

        Returns
        - the final knockback
        """
        ...


    def setFinalKnockback(self, knockback: "Vector") -> None:
        """
        Sets the force that will be applied to the entity.

        Arguments
        - knockback: the force to apply
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class KnockbackCause(Enum):
        """
        An enum to specify the cause of the knockback.
        """

        DAMAGE = 0
        """
        Knockback caused by non-entity damage.
        """
        ENTITY_ATTACK = 1
        """
        Knockback caused by an attacking entity.
        """
        EXPLOSION = 2
        """
        Knockback caused by an explosion.
        """
        SHIELD_BLOCK = 3
        """
        Knockback caused by the target blocking with a shield.
        """
        SWEEP_ATTACK = 4
        """
        Knockback caused by a sweeping attack.
        """
        UNKNOWN = 5
        """
        Knockback with an unknown cause.
        """



"""
Python module generated from Java source file com.google.common.io.CharSink

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import BufferedWriter
from java.io import IOException
from java.io import Reader
from java.io import Writer
from java.nio.charset import Charset
from java.util import Iterator
from java.util.stream import Stream
from typing import Any, Callable, Iterable, Tuple


class CharSink:
    """
    A destination to which characters can be written, such as a text file. Unlike a Writer, a
    `CharSink` is not an open, stateful stream that can be written to and closed. Instead, it
    is an immutable *supplier* of `Writer` instances.
    
    `CharSink` provides two kinds of methods:
    
    
      - **Methods that return a writer:** These methods should return a *new*, independent
          instance each time they are called. The caller is responsible for ensuring that the
          returned writer is closed.
      - **Convenience methods:** These are implementations of common operations that are
          typically implemented by opening a writer using one of the methods in the first category,
          doing something and finally closing the writer that was opened.
    
    
    Any ByteSink may be viewed as a `CharSink` with a specific Charset
    character encoding using ByteSink.asCharSink(Charset). Characters written to the
    resulting `CharSink` will written to the `ByteSink` as encoded bytes.

    Author(s)
    - Colin Decker

    Since
    - 14.0
    """

    def openStream(self) -> "Writer":
        """
        Opens a new Writer for writing to this sink. This method returns a new, independent
        writer each time it is called.
        
        The caller is responsible for ensuring that the returned writer is closed.

        Raises
        - IOException: if an I/O error occurs while opening the writer
        """
        ...


    def openBufferedStream(self) -> "Writer":
        """
        Opens a new buffered Writer for writing to this sink. The returned stream is not
        required to be a BufferedWriter in order to allow implementations to simply delegate to
        .openStream() when the stream returned by that method does not benefit from additional
        buffering. This method returns a new, independent writer each time it is called.
        
        The caller is responsible for ensuring that the returned writer is closed.

        Raises
        - IOException: if an I/O error occurs while opening the writer

        Since
        - 15.0 (in 14.0 with return type BufferedWriter)
        """
        ...


    def write(self, charSequence: "CharSequence") -> None:
        """
        Writes the given character sequence to this sink.

        Raises
        - IOException: if an I/O error while writing to this sink
        """
        ...


    def writeLines(self, lines: Iterable["CharSequence"]) -> None:
        """
        Writes the given lines of text to this sink with each line (including the last) terminated with
        the operating system's default line separator. This method is equivalent to `writeLines(lines, System.getProperty("line.separator"))`.

        Raises
        - IOException: if an I/O error occurs while writing to this sink
        """
        ...


    def writeLines(self, lines: Iterable["CharSequence"], lineSeparator: str) -> None:
        """
        Writes the given lines of text to this sink with each line (including the last) terminated with
        the given line separator.

        Raises
        - IOException: if an I/O error occurs while writing to this sink
        """
        ...


    def writeLines(self, lines: "Stream"["CharSequence"]) -> None:
        """
        Writes the given lines of text to this sink with each line (including the last) terminated with
        the operating system's default line separator. This method is equivalent to `writeLines(lines, System.getProperty("line.separator"))`.

        Raises
        - IOException: if an I/O error occurs while writing to this sink

        Since
        - 22.0
        """
        ...


    def writeLines(self, lines: "Stream"["CharSequence"], lineSeparator: str) -> None:
        """
        Writes the given lines of text to this sink with each line (including the last) terminated with
        the given line separator.

        Raises
        - IOException: if an I/O error occurs while writing to this sink

        Since
        - 22.0
        """
        ...


    def writeFrom(self, readable: "Readable") -> int:
        """
        Writes all the text from the given Readable (such as a Reader) to this sink.
        Does not close `readable` if it is `Closeable`.

        Returns
        - the number of characters written

        Raises
        - IOException: if an I/O error occurs while reading from `readable` or writing to
            this sink
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.MacHashFunction

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.hash import *
from com.google.errorprone.annotations import Immutable
from java.security import InvalidKeyException
from java.security import Key
from java.security import NoSuchAlgorithmException
from javax.crypto import Mac
from typing import Any, Callable, Iterable, Tuple


class MacHashFunction(AbstractHashFunction):
    """
    HashFunction adapter for Mac instances.

    Author(s)
    - Kurt Alfred Kluever
    """

    def bits(self) -> int:
        ...


    def newHasher(self) -> "Hasher":
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.io.ByteArrayDataInput

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import DataInput
from java.io import IOException
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ByteArrayDataInput(DataInput):
    """
    An extension of `DataInput` for reading from in-memory byte arrays; its methods offer
    identical functionality but do not throw IOException.
    
    **Warning:** The caller is responsible for not attempting to read past the end of the
    array. If any method encounters the end of the array prematurely, it throws IllegalStateException to signify *programmer error*. This behavior is a technical violation
    of the supertype's contract, which specifies a checked exception.

    Author(s)
    - Kevin Bourrillion

    Since
    - 1.0
    """

    def readFully(self, b: list[int]) -> None:
        ...


    def readFully(self, b: list[int], off: int, len: int) -> None:
        ...


    def skipBytes(self, n: int) -> int:
        ...


    def readBoolean(self) -> bool:
        ...


    def readByte(self) -> int:
        ...


    def readUnsignedByte(self) -> int:
        ...


    def readShort(self) -> int:
        ...


    def readUnsignedShort(self) -> int:
        ...


    def readChar(self) -> str:
        ...


    def readInt(self) -> int:
        ...


    def readLong(self) -> int:
        ...


    def readFloat(self) -> float:
        ...


    def readDouble(self) -> float:
        ...


    def readLine(self) -> str:
        ...


    def readUTF(self) -> str:
        ...



from .MethodProperty import MethodProperty
from .BeanAccess import BeanAccess
from .FieldProperty import FieldProperty
from .GenericProperty import GenericProperty
from .Property import Property
from .PropertyUtils import PropertyUtils
from .PropertySubstitute import PropertySubstitute
from .MissingProperty import MissingProperty


"""
Python module generated from Java source file org.bukkit.generator.BiomeProvider

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Biome
from org.bukkit.generator import *
from typing import Any, Callable, Iterable, Tuple


class BiomeProvider:
    """
    Class for providing biomes.
    """

    def getBiome(self, worldInfo: "WorldInfo", x: int, y: int, z: int) -> "Biome":
        """
        Return the Biome which should be present at the provided location.
        
        Notes:
        
        This method **must** be completely thread safe and able to handle
        multiple concurrent callers.
        
        This method should only return biomes which are present in the list
        returned by .getBiomes(WorldInfo)
        
        This method should **never** return Biome.CUSTOM.

        Arguments
        - worldInfo: The world info of the world the biome will be used for
        - x: The X-coordinate from world origin
        - y: The Y-coordinate from world origin
        - z: The Z-coordinate from world origin

        Returns
        - Biome for the given location
        """
        ...


    def getBiome(self, worldInfo: "WorldInfo", x: int, y: int, z: int, biomeParameterPoint: "BiomeParameterPoint") -> "Biome":
        """
        Return the Biome which should be present at the provided location.
        
        Notes:
        
        This method **must** be completely thread safe and able to handle
        multiple concurrent callers.
        
        This method should only return biomes which are present in the list
        returned by .getBiomes(WorldInfo)
        
        This method should **never** return Biome.CUSTOM.
        Only this method is called if both this and
        .getBiome(WorldInfo, int, int, int) are overridden.

        Arguments
        - worldInfo: The world info of the world the biome will be used for
        - x: The X-coordinate from world origin
        - y: The Y-coordinate from world origin
        - z: The Z-coordinate from world origin
        - biomeParameterPoint: The parameter point that is provided by default
                              for this location (contains temperature, humidity,
                              continentalness, erosion, depth and weirdness)

        Returns
        - Biome for the given location

        See
        - .getBiome(WorldInfo, int, int, int)
        """
        ...


    def getBiomes(self, worldInfo: "WorldInfo") -> list["Biome"]:
        """
        Returns a list with every biome the BiomeProvider will use for
        the given world.
        
        Notes:
        
        This method only gets called once, when the world is loaded. Returning
        another list or modifying the values from the initial returned list later
        one, are not respected.
        
        This method should **never** return a list which contains
        Biome.CUSTOM.

        Arguments
        - worldInfo: The world info of the world the list will be used for

        Returns
        - A list with every biome the BiomeProvider uses
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Piglin

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.entity import *
from org.bukkit.inventory import InventoryHolder
from typing import Any, Callable, Iterable, Tuple


class Piglin(PiglinAbstract, InventoryHolder):
    """
    Represents a Piglin.
    """

    def isAbleToHunt(self) -> bool:
        """
        Get whether the piglin is able to hunt hoglins.

        Returns
        - Whether the piglin is able to hunt hoglins
        """
        ...


    def setIsAbleToHunt(self, flag: bool) -> None:
        """
        Sets whether the piglin is able to hunt hoglins.

        Arguments
        - flag: Whether the piglin is able to hunt hoglins.
        """
        ...


    def addBarterMaterial(self, material: "Material") -> bool:
        """
        Adds a material to the allowed list of materials to barter with.

        Arguments
        - material: The material to add

        Returns
        - True if the item has been added successfully, False otherwise
        """
        ...


    def removeBarterMaterial(self, material: "Material") -> bool:
        """
        Removes a material from the allowed list of materials to barter with.
        
        <strong>Note:</strong> It's not possible to override the default
        bartering item gold_ingots as payment. To block gold_ingots see
        org.bukkit.event.entity.PiglinBarterEvent.

        Arguments
        - material: The material to remove

        Returns
        - True if the item has been removed successfully, False otherwise
        """
        ...


    def addMaterialOfInterest(self, material: "Material") -> bool:
        """
        Adds a material the piglin will pickup and store in his inventory.

        Arguments
        - material: The material you want the piglin to be interested in

        Returns
        - True if the item has been added successfully, False otherwise
        """
        ...


    def removeMaterialOfInterest(self, material: "Material") -> bool:
        """
        Removes a material from the list of materials the piglin will pickup.
        
        <strong>Note:</strong> It's not possible to override the default list of
        item the piglin will pickup. To cancel pickup see
        org.bukkit.event.entity.EntityPickupItemEvent.

        Arguments
        - material: The material you want removed from the interest list

        Returns
        - True if the item has been removed successfully, False otherwise
        """
        ...


    def getInterestList(self) -> set["Material"]:
        """
        Returns a immutable set of materials the piglins will pickup.
        
        <strong>Note:</strong> This set will not include the items that are set
        by default. To interact with those items see
        org.bukkit.event.entity.EntityPickupItemEvent.

        Returns
        - An immutable materials set
        """
        ...


    def getBarterList(self) -> set["Material"]:
        """
        Returns a immutable set of materials the piglins will barter with.
        
        <strong>Note:</strong> This set will not include the items that are set
        by default. To interact with those items see
        org.bukkit.event.entity.PiglinBarterEvent.

        Returns
        - An immutable materials set
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.bind.SerializationDelegatingTypeAdapter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import TypeAdapter
from com.google.gson.internal.bind import *
from typing import Any, Callable, Iterable, Tuple


class SerializationDelegatingTypeAdapter(TypeAdapter):
    """
    Type adapter which might delegate serialization to another adapter.
    """

    def getSerializationDelegate(self) -> "TypeAdapter"["T"]:
        """
        Returns the adapter used for serialization, might be `this` or another adapter. That
        other adapter might itself also be a `SerializationDelegatingTypeAdapter`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.view.LoomView

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.banner import PatternType
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory import LoomInventory
from org.bukkit.inventory.view import *
from typing import Any, Callable, Iterable, Tuple


class LoomView(InventoryView):
    """
    An instance of InventoryView which provides extra methods related to
    loom view data.
    """

    def getTopInventory(self) -> "LoomInventory":
        ...


    def getSelectablePatterns(self) -> list["PatternType"]:
        """
        Gets a list of all selectable to the player.

        Returns
        - A copy of the PatternType's currently selectable by the
        player
        """
        ...


    def getSelectedPatternIndex(self) -> int:
        """
        Gets an index of the selected pattern.

        Returns
        - Index of the selected pattern
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingSetMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingSetMultimap(ForwardingMultimap, SetMultimap):
    """
    A set multimap which forwards all its method calls to another set multimap. Subclasses should
    override one or more methods to modify the behavior of the backing multimap as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingSetMultimap`.

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 3.0
    """

    def entries(self) -> set["Entry"["K", "V"]]:
        ...


    def get(self, key: "K") -> set["V"]:
        ...


    def removeAll(self, key: "Object") -> set["V"]:
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> set["V"]:
        ...



"""
Python module generated from Java source file com.google.common.collect.FilteredKeySetMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Predicate
from com.google.common.collect import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class FilteredKeySetMultimap(FilteredKeyMultimap, FilteredSetMultimap):
    """
    Implementation of Multimaps.filterKeys(SetMultimap, Predicate).

    Author(s)
    - Louis Wasserman
    """

    def unfiltered(self) -> "SetMultimap"["K", "V"]:
        ...


    def get(self, key: "K") -> set["V"]:
        ...


    def removeAll(self, key: "Object") -> set["V"]:
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> set["V"]:
        ...


    def entries(self) -> set["Entry"["K", "V"]]:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Cake

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Cake(BlockData):
    """
    'bites' represents the amount of bites which have been taken from this slice
    of cake.
    
    A value of 0 indicates that the cake has not been eaten, whilst a value of
    .getMaximumBites() indicates that it is all gone :(
    """

    def getBites(self) -> int:
        """
        Gets the value of the 'bites' property.

        Returns
        - the 'bites' value
        """
        ...


    def setBites(self, bites: int) -> None:
        """
        Sets the value of the 'bites' property.

        Arguments
        - bites: the new 'bites' value
        """
        ...


    def getMaximumBites(self) -> int:
        """
        Gets the maximum allowed value of the 'bites' property.

        Returns
        - the maximum 'bites' value
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.events.Event

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class Event:
    """
    Basic unit of output from a org.yaml.snakeyaml.parser.Parser or input of a
    org.yaml.snakeyaml.emitter.Emitter.
    """

    def __init__(self, startMark: "Mark", endMark: "Mark"):
        """
        Create

        Arguments
        - startMark: - start
        - endMark: - end
        """
        ...


    def toString(self) -> str:
        ...


    def getStartMark(self) -> "Mark":
        """
        getter

        Returns
        - start
        """
        ...


    def getEndMark(self) -> "Mark":
        """
        getter

        Returns
        - end
        """
        ...


    def is(self, id: "Event.ID") -> bool:
        """
        Check if the Event is of the provided kind

        Arguments
        - id: - the Event.ID enum

        Returns
        - True then this Event of the provided type
        """
        ...


    def getEventId(self) -> "Event.ID":
        """
        Get the type (kind) if this Event

        Returns
        - the ID of this Event
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    class ID(Enum):
        """
        Event types
        """

        Alias = 0
        Comment = 1
        DocumentEnd = 2
        DocumentStart = 3
        MappingEnd = 4
        MappingStart = 5
        Scalar = 6
        SequenceEnd = 7
        SequenceStart = 8
        StreamEnd = 9
        StreamStart = 10



"""
Python module generated from Java source file com.google.common.util.concurrent.SettableFuture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SettableFuture(TrustedFuture):
    """
    A ListenableFuture whose result can be set by a .set(Object), .setException(Throwable) or .setFuture(ListenableFuture) call. It can also, like any
    other `Future`, be .cancel cancelled.
    
    `SettableFuture` is the recommended `ListenableFuture` implementation when your
    task cannot be implemented with ListeningExecutorService, the various Futures
    utility methods, or ListenableFutureTask. Those APIs have less opportunity for developer
    error. If your needs are more complex than `SettableFuture` supports, use AbstractFuture, which offers an extensible version of the API.

    Author(s)
    - Sven Mawson

    Since
    - 9.0 (in 1.0 as `ValueFuture`)
    """

    @staticmethod
    def create() -> "SettableFuture"["V"]:
        """
        Creates a new `SettableFuture` that can be completed or cancelled by a later method call.
        """
        ...


    def set(self, value: "V") -> bool:
        ...


    def setException(self, throwable: "Throwable") -> bool:
        ...


    def setFuture(self, future: "ListenableFuture"["V"]) -> bool:
        ...



"""
Python module generated from Java source file java.nio.charset.CoderResult

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.charset import *
from java.util.concurrent import ConcurrentHashMap
from typing import Any, Callable, Iterable, Tuple


class CoderResult:

    UNDERFLOW = CoderResult(CR_UNDERFLOW, 0)
    """
    Result object indicating underflow, meaning that either the input buffer
    has been completely consumed or, if the input buffer is not yet empty,
    that additional input is required.
    """
    OVERFLOW = CoderResult(CR_OVERFLOW, 0)
    """
    Result object indicating overflow, meaning that there is insufficient
    room in the output buffer.
    """


    def toString(self) -> str:
        """
        Returns a string describing this coder result.

        Returns
        - A descriptive string
        """
        ...


    def isUnderflow(self) -> bool:
        """
        Tells whether or not this object describes an underflow condition.

        Returns
        - `True` if, and only if, this object denotes underflow
        """
        ...


    def isOverflow(self) -> bool:
        """
        Tells whether or not this object describes an overflow condition.

        Returns
        - `True` if, and only if, this object denotes overflow
        """
        ...


    def isError(self) -> bool:
        """
        Tells whether or not this object describes an error condition.

        Returns
        - `True` if, and only if, this object denotes either a
                 malformed-input error or an unmappable-character error
        """
        ...


    def isMalformed(self) -> bool:
        """
        Tells whether or not this object describes a malformed-input error.

        Returns
        - `True` if, and only if, this object denotes a
                 malformed-input error
        """
        ...


    def isUnmappable(self) -> bool:
        """
        Tells whether or not this object describes an unmappable-character
        error.

        Returns
        - `True` if, and only if, this object denotes an
                 unmappable-character error
        """
        ...


    def length(self) -> int:
        """
        Returns the length of the erroneous input described by this
        object&nbsp;&nbsp;*(optional operation)*.

        Returns
        - The length of the erroneous input, a positive integer

        Raises
        - UnsupportedOperationException: If this object does not describe an error condition, that is,
                 if the .isError() isError does not return `True`
        """
        ...


    @staticmethod
    def malformedForLength(length: int) -> "CoderResult":
        """
        Static factory method that returns the unique object describing a
        malformed-input error of the given length.

        Arguments
        - length: The given length

        Returns
        - The requested coder-result object
        """
        ...


    @staticmethod
    def unmappableForLength(length: int) -> "CoderResult":
        """
        Static factory method that returns the unique result object describing
        an unmappable-character error of the given length.

        Arguments
        - length: The given length

        Returns
        - The requested coder-result object
        """
        ...


    def throwException(self) -> None:
        """
        Throws an exception appropriate to the result described by this object.

        Raises
        - BufferUnderflowException: If this object is .UNDERFLOW
        - BufferOverflowException: If this object is .OVERFLOW
        - MalformedInputException: If this object represents a malformed-input error; the
                 exception's length value will be that of this object
        - UnmappableCharacterException: If this object represents an unmappable-character error; the
                 exceptions length value will be that of this object
        """
        ...



"""
Python module generated from Java source file org.bukkit.structure.StructureManager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import File
from java.io import IOException
from java.io import InputStream
from java.io import OutputStream
from org.bukkit import NamespacedKey
from org.bukkit.structure import *
from typing import Any, Callable, Iterable, Tuple


class StructureManager:

    def getStructures(self) -> dict["NamespacedKey", "Structure"]:
        """
        Gets the currently registered structures.
        
        These are the currently loaded structures that the StructureManager is
        aware of. When a structure block refers to a structure, these structures
        are checked first. If the specified structure is not found among the
        currently registered structures, the StructureManager may dynamically
        read the structure from the primary world folder, DataPacks, or the
        server's own resources. Structures can be registered via .registerStructure(NamespacedKey, Structure)

        Returns
        - an unmodifiable shallow copy of the currently registered
        structures
        """
        ...


    def getStructure(self, structureKey: "NamespacedKey") -> "Structure":
        """
        Gets a registered Structure.

        Arguments
        - structureKey: The key for which to get the structure

        Returns
        - The structure that belongs to the structureKey or
        `null` if there is none registered for that key.
        """
        ...


    def registerStructure(self, structureKey: "NamespacedKey", structure: "Structure") -> "Structure":
        """
        Registers the given structure. See .getStructures().

        Arguments
        - structureKey: The key for which to register the structure
        - structure: The structure to register

        Returns
        - The structure for the specified key, or `null` if the
        structure could not be found.
        """
        ...


    def unregisterStructure(self, structureKey: "NamespacedKey") -> "Structure":
        """
        Unregisters a structure. Unregisters the specified structure. If the
        structure still exists in the primary world folder, a DataPack, or is
        part of the server's own resources, it may be loaded and registered again
        when it is requested by a plugin or the server itself.

        Arguments
        - structureKey: The key for which to save the structure for

        Returns
        - The structure that was registered for that key or
        `null` if there was none
        """
        ...


    def loadStructure(self, structureKey: "NamespacedKey", register: bool) -> "Structure":
        """
        Loads a structure for the specified key and optionally .registerStructure(NamespacedKey, Structure) registers it.
        
        This will first check the already loaded .getStructures()
        registered structures, and otherwise load the structure from the primary
        world folder, DataPacks, and the server's own resources (in this order).
        
        When loading the structure from the primary world folder, the given key
        is translated to a file as specified by
        .getStructureFile(NamespacedKey).

        Arguments
        - structureKey: The key for which to load the structure
        - register: `True` to register the loaded structure.

        Returns
        - The structure, or `null` if no structure was found for
        the specified key
        """
        ...


    def loadStructure(self, structureKey: "NamespacedKey") -> "Structure":
        """
        Loads the structure for the specified key and automatically registers it.
        See .loadStructure(NamespacedKey, boolean).

        Arguments
        - structureKey: The key for which to load the structure

        Returns
        - The structure for the specified key, or `null` if the
        structure could not be found.
        """
        ...


    def saveStructure(self, structureKey: "NamespacedKey") -> None:
        """
        Saves the currently .getStructures() registered structure for the
        specified NamespacedKey key to the primary world folder as
        specified by {#getStructureFile(NamespacedKey}.

        Arguments
        - structureKey: The key for which to save the structure for
        """
        ...


    def saveStructure(self, structureKey: "NamespacedKey", structure: "Structure") -> None:
        """
        Saves a structure with a given key to the primary world folder.

        Arguments
        - structureKey: The key for which to save the structure for
        - structure: The structure to save for this structureKey
        """
        ...


    def deleteStructure(self, structureKey: "NamespacedKey") -> None:
        """
        Unregisters the specified structure and deletes its .getStructureFile(NamespacedKey) structure file from the primary world
        folder. Note that this method cannot be used to delete vanilla Minecraft
        structures, or structures from DataPacks. Unregistering these structures
        will however work fine.

        Arguments
        - structureKey: The key of the structure to remove

        Raises
        - IOException: If the file could not be removed for some reason.
        """
        ...


    def deleteStructure(self, structureKey: "NamespacedKey", unregister: bool) -> None:
        """
        Deletes the .getStructureFile(NamespacedKey) structure file for
        the specified structure from the primary world folder. Note that this
        method cannot be used to delete vanilla Minecraft structures, or
        structures from DataPacks. Unregistering these structures will however
        work fine.

        Arguments
        - structureKey: The key of the structure to remove
        - unregister: Whether to also unregister the specified structure if
        it is currently loaded.

        Raises
        - IOException: If the file could not be removed for some reason.
        """
        ...


    def getStructureFile(self, structureKey: "NamespacedKey") -> "File":
        """
        Gets the location where a structure file would exist in the primary world
        directory based on the NamespacedKey using the format
        world/generated/{NAMESPACE}/structures/{KEY}.nbt. This method will always
        return a file, even if none exists at the moment.

        Arguments
        - structureKey: The key to build the filepath from.

        Returns
        - The location where a file with this key would be.
        """
        ...


    def loadStructure(self, file: "File") -> "Structure":
        """
        Reads a Structure from disk.

        Arguments
        - file: The file of the structure

        Returns
        - The read structure

        Raises
        - IOException: when the given file can not be read from
        """
        ...


    def loadStructure(self, inputStream: "InputStream") -> "Structure":
        """
        Reads a Structure from a stream.

        Arguments
        - inputStream: The file of the structure

        Returns
        - The read Structure
        """
        ...


    def saveStructure(self, file: "File", structure: "Structure") -> None:
        """
        Save a structure to a file. This will overwrite a file if it already
        exists.

        Arguments
        - file: the target to save to.
        - structure: the Structure to save.

        Raises
        - IOException: when the given file can not be written to.
        """
        ...


    def saveStructure(self, outputStream: "OutputStream", structure: "Structure") -> None:
        """
        Save a structure to a stream.

        Arguments
        - outputStream: the stream to write to.
        - structure: the Structure to save.

        Raises
        - IOException: when the given file can not be written to.
        """
        ...


    def createStructure(self) -> "Structure":
        """
        Creates a new empty structure.

        Returns
        - an empty structure.
        """
        ...


    def copy(self, structure: "Structure") -> "Structure":
        """
        Creates a copy of this structure.

        Arguments
        - structure: The structure to copy

        Returns
        - a copy of the structure
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.view.MerchantView

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory import Merchant
from org.bukkit.inventory import MerchantInventory
from org.bukkit.inventory.view import *
from typing import Any, Callable, Iterable, Tuple


class MerchantView(InventoryView):
    """
    An instance of InventoryView which provides extra methods related to
    merchant view data.
    """

    def getTopInventory(self) -> "MerchantInventory":
        ...


    def getMerchant(self) -> "Merchant":
        """
        Gets the merchant that this view is for.

        Returns
        - The merchant that this view uses
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.sign.SignSide

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.sign import *
from org.bukkit.material import Colorable
from typing import Any, Callable, Iterable, Tuple


class SignSide(Colorable):
    """
    Represents a side of a sign.
    """

    def getLines(self) -> list[str]:
        """
        Gets all the lines of text currently on this side of the sign.

        Returns
        - Array of Strings containing each line of text
        """
        ...


    def getLine(self, index: int) -> str:
        """
        Gets the line of text at the specified index on this side of the sign.
        
        For example, getLine(0) will return the first line of text.

        Arguments
        - index: Line number to get the text from, starting at 0

        Returns
        - Text on the given line

        Raises
        - IndexOutOfBoundsException: Thrown when the line does not exist
        """
        ...


    def setLine(self, index: int, line: str) -> None:
        """
        Sets the line of text at the specified index on this side of the sign.
        
        For example, setLine(0, "Line One") will set the first line of text to
        "Line One".

        Arguments
        - index: Line number to set the text at, starting from 0
        - line: New text to set at the specified index

        Raises
        - IndexOutOfBoundsException: If the index is out of the range 0..3
        """
        ...


    def isGlowingText(self) -> bool:
        """
        Gets whether this side of the sign has glowing text.

        Returns
        - if this side of the sign has glowing text
        """
        ...


    def setGlowingText(self, glowing: bool) -> None:
        """
        Sets whether this side of the sign has glowing text.

        Arguments
        - glowing: if this side of the sign has glowing text
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.events.CollectionStartEvent

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class CollectionStartEvent(NodeEvent):
    """
    Base class for the start events of the collection nodes.
    """

    def __init__(self, anchor: str, tag: str, implicit: bool, startMark: "Mark", endMark: "Mark", flowStyle: "DumperOptions.FlowStyle"):
        """
        Create

        Arguments
        - anchor: - its anchor
        - tag: - its tag
        - implicit: - thue when the tag is implicitly resolved
        - startMark: - start
        - endMark: - end
        - flowStyle: - style
        """
        ...


    def getTag(self) -> str:
        """
        Tag of this collection.

        Returns
        - The tag of this collection, or `null` if no explicit tag is available.
        """
        ...


    def getImplicit(self) -> bool:
        """
        `True` if the tag can be omitted while this collection is emitted.

        Returns
        - True if the tag can be omitted while this collection is emitted.
        """
        ...


    def getFlowStyle(self) -> "DumperOptions.FlowStyle":
        """
        `True` if this collection is in flow style, `False` for block style.

        Returns
        - If this collection is in flow style.
        """
        ...


    def isFlow(self) -> bool:
        """
        Getter

        Returns
        - True for FLOW (exclude BLOCK and AUTO)
        """
        ...



"""
Python module generated from Java source file com.google.common.eventbus.DeadEvent

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import MoreObjects
from com.google.common.eventbus import *
from typing import Any, Callable, Iterable, Tuple


class DeadEvent:
    """
    Wraps an event that was posted, but which had no subscribers and thus could not be delivered.
    
    Registering a DeadEvent subscriber is useful for debugging or logging, as it can detect
    misconfigurations in a system's event distribution.

    Author(s)
    - Cliff Biffle

    Since
    - 10.0
    """

    def __init__(self, source: "Object", event: "Object"):
        """
        Creates a new DeadEvent.

        Arguments
        - source: object broadcasting the DeadEvent (generally the EventBus).
        - event: the event that could not be delivered.
        """
        ...


    def getSource(self) -> "Object":
        """
        Returns the object that originated this event (*not* the object that originated the
        wrapped event). This is generally an EventBus.

        Returns
        - the source of this event.
        """
        ...


    def getEvent(self) -> "Object":
        """
        Returns the wrapped, 'dead' event, which the system was unable to deliver to any registered
        subscriber.

        Returns
        - the 'dead' event that could not be delivered.
        """
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.view.FurnaceView

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Furnace
from org.bukkit.inventory import FurnaceInventory
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory.view import *
from typing import Any, Callable, Iterable, Tuple


class FurnaceView(InventoryView):
    """
    An instance of InventoryView which provides extra methods related to
    furnace view data.
    """

    def getTopInventory(self) -> "FurnaceInventory":
        ...


    def getCookTime(self) -> float:
        """
        The cook time for this view.
        
        See Furnace.getCookTime() for more information.

        Returns
        - a number between 0 and 1
        """
        ...


    def getBurnTime(self) -> float:
        """
        The total burn time for this view.
        
        See Furnace.getBurnTime() for more information.

        Returns
        - a number between 0 and 1
        """
        ...


    def isBurning(self) -> bool:
        """
        Checks whether or not the furnace is burning

        Returns
        - True given that the furnace is burning
        """
        ...


    def setCookTime(self, cookProgress: int, cookDuration: int) -> None:
        """
        Sets the cook time
        
        Setting cook time requires manipulation of both cookProgress and
        cookDuration. This method does a simple division to get total progress
        within the furnaces visual duration bar. For a clear visual effect
        (cookProgress / cookDuration) should return a number between 0 and 1
        inclusively.

        Arguments
        - cookProgress: the current of the cooking
        - cookDuration: the total cook time
        """
        ...


    def setBurnTime(self, burnProgress: int, burnDuration: int) -> None:
        """
        Sets the burn time
        
        Setting burn time requires manipulation of both burnProgress and
        burnDuration. This method does a simple division to get total progress
        within the furnaces visual burning bar. For a clear visual effect
        (burnProgress / burnDuration) should return a number between 0 and 1
        inclusively.

        Arguments
        - burnProgress: the progress towards the burnDuration
        - burnDuration: the total duration the view should be lit
        """
        ...



"""
Python module generated from Java source file org.bukkit.Effect

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Maps
from enum import Enum
from org.bukkit import *
from org.bukkit.block import BlockFace
from typing import Any, Callable, Iterable, Tuple


class Effect(Enum):
    """
    A list of effects that the server is able to send to players.
    """

    CLICK2 = (1000, Type.SOUND)
    """
    An alternate click sound.
    """
    CLICK1 = (1001, Type.SOUND)
    """
    A click sound.
    """
    BOW_FIRE = (1002, Type.SOUND)
    """
    Sound of a bow firing.
    """
    DOOR_TOGGLE = (1006, Type.SOUND)
    """
    Sound of a door opening.

    See
    - Sound.BLOCK_WOODEN_DOOR_OPEN

    Deprecated
    - no longer exists
    """
    IRON_DOOR_TOGGLE = (1005, Type.SOUND)
    """
    Sound of a door opening.

    See
    - Sound.BLOCK_IRON_DOOR_OPEN

    Deprecated
    - no longer exists
    """
    TRAPDOOR_TOGGLE = (1007, Type.SOUND)
    """
    Sound of a trapdoor opening.

    See
    - Sound.BLOCK_WOODEN_TRAPDOOR_OPEN

    Deprecated
    - no longer exists
    """
    IRON_TRAPDOOR_TOGGLE = (1037, Type.SOUND)
    """
    Sound of a door opening.

    See
    - Sound.BLOCK_IRON_TRAPDOOR_OPEN

    Deprecated
    - no longer exists
    """
    FENCE_GATE_TOGGLE = (1008, Type.SOUND)
    """
    Sound of a door opening.

    See
    - Sound.BLOCK_FENCE_GATE_OPEN

    Deprecated
    - no longer exists
    """
    DOOR_CLOSE = (1012, Type.SOUND)
    """
    Sound of a door closing.

    See
    - Sound.BLOCK_WOODEN_DOOR_CLOSE

    Deprecated
    - no longer exists
    """
    IRON_DOOR_CLOSE = (1011, Type.SOUND)
    """
    Sound of a door closing.

    See
    - Sound.BLOCK_IRON_DOOR_CLOSE

    Deprecated
    - no longer exists
    """
    TRAPDOOR_CLOSE = (1013, Type.SOUND)
    """
    Sound of a trapdoor closing.

    See
    - Sound.BLOCK_WOODEN_TRAPDOOR_CLOSE

    Deprecated
    - no longer exists
    """
    IRON_TRAPDOOR_CLOSE = (1036, Type.SOUND)
    """
    Sound of a door closing.

    See
    - Sound.BLOCK_IRON_TRAPDOOR_CLOSE

    Deprecated
    - no longer exists
    """
    FENCE_GATE_CLOSE = (1014, Type.SOUND)
    """
    Sound of a door closing.

    See
    - Sound.BLOCK_FENCE_GATE_CLOSE

    Deprecated
    - no longer exists
    """
    EXTINGUISH = (1009, Type.SOUND)
    """
    Sound of fire being extinguished.
    """
    RECORD_PLAY = (1010, Type.SOUND, Material)
    """
    A song from a record. Needs the record item ID as additional info
    """
    GHAST_SHRIEK = (1015, Type.SOUND)
    """
    Sound of ghast shrieking.
    """
    GHAST_SHOOT = (1016, Type.SOUND)
    """
    Sound of ghast firing.
    """
    BLAZE_SHOOT = (1018, Type.SOUND)
    """
    Sound of blaze firing.
    """
    ZOMBIE_CHEW_WOODEN_DOOR = (1019, Type.SOUND)
    """
    Sound of zombies chewing on wooden doors.
    """
    ZOMBIE_CHEW_IRON_DOOR = (1020, Type.SOUND)
    """
    Sound of zombies chewing on iron doors.
    """
    ZOMBIE_DESTROY_DOOR = (1021, Type.SOUND)
    """
    Sound of zombies destroying a door.
    """
    SMOKE = (2000, Type.VISUAL, BlockFace)
    """
    A visual smoke effect. Needs direction as additional info.
    """
    STEP_SOUND = (2001, Type.SOUND, Material)
    """
    Sound of a block breaking. Needs block ID as additional info.
    """
    POTION_BREAK = (2002, Type.VISUAL, Color)
    """
    Visual effect of a splash potion breaking. Needs potion data value as
    additional info.
    """
    INSTANT_POTION_BREAK = (2007, Type.VISUAL, Color)
    """
    Visual effect of an instant splash potion breaking. Needs color data
    value as additional info.
    """
    ENDER_SIGNAL = (2003, Type.VISUAL)
    """
    An ender eye signal; a visual effect.
    """
    MOBSPAWNER_FLAMES = (2004, Type.VISUAL)
    """
    The flames seen on a mobspawner; a visual effect.
    """
    BREWING_STAND_BREW = (1035, Type.SOUND)
    """
    The sound played by brewing stands when brewing
    """
    CHORUS_FLOWER_GROW = (1033, Type.SOUND)
    """
    The sound played when a chorus flower grows
    """
    CHORUS_FLOWER_DEATH = (1034, Type.SOUND)
    """
    The sound played when a chorus flower dies
    """
    PORTAL_TRAVEL = (1032, Type.SOUND)
    """
    The sound played when traveling through a portal
    """
    ENDEREYE_LAUNCH = (1003, Type.SOUND)
    """
    The sound played when launching an endereye
    """
    FIREWORK_SHOOT = (1004, Type.SOUND)
    """
    The sound played when launching a firework
    """
    VILLAGER_PLANT_GROW = (2005, Type.VISUAL, Integer)
    """
    Particles displayed when a villager grows a plant, data
    is the number of particles
    """
    DRAGON_BREATH = (2006, Type.VISUAL)
    """
    The sound/particles used by the enderdragon's breath
    attack.
    """
    ANVIL_BREAK = (1029, Type.SOUND)
    """
    The sound played when an anvil breaks
    """
    ANVIL_USE = (1030, Type.SOUND)
    """
    The sound played when an anvil is used
    """
    ANVIL_LAND = (1031, Type.SOUND)
    """
    The sound played when an anvil lands after
    falling
    """
    ENDERDRAGON_SHOOT = (1017, Type.SOUND)
    """
    Sound of an enderdragon firing
    """
    WITHER_BREAK_BLOCK = (1022, Type.SOUND)
    """
    The sound played when a wither breaks a block
    """
    WITHER_SHOOT = (1024, Type.SOUND)
    """
    Sound of a wither shooting
    """
    ZOMBIE_INFECT = (1026, Type.SOUND)
    """
    The sound played when a zombie infects a target
    """
    ZOMBIE_CONVERTED_VILLAGER = (1027, Type.SOUND)
    """
    The sound played when a villager is converted by
    a zombie
    """
    BAT_TAKEOFF = (1025, Type.SOUND)
    """
    Sound played by a bat taking off
    """
    END_GATEWAY_SPAWN = (3000, Type.VISUAL)
    """
    The sound/particles caused by a end gateway spawning
    """
    ENDERDRAGON_GROWL = (3001, Type.SOUND)
    """
    The sound of an enderdragon growling
    """
    PHANTOM_BITE = (1039, Type.SOUND)
    """
    The sound played when phantom bites.
    """
    ZOMBIE_CONVERTED_TO_DROWNED = (1040, Type.SOUND)
    """
    The sound played when a zombie converts to a drowned.
    """
    HUSK_CONVERTED_TO_ZOMBIE = (1041, Type.SOUND)
    """
    The sound played when a husk converts to a zombie.
    """
    GRINDSTONE_USE = (1042, Type.SOUND)
    """
    The sound played when a grindstone is being used.
    """
    BOOK_PAGE_TURN = (1043, Type.SOUND)
    """
    The sound played when a book page is being turned.
    """
    SMITHING_TABLE_USE = (1044, Type.SOUND)
    """
    The sound played when a smithing table is being used.
    """
    POINTED_DRIPSTONE_LAND = (1045, Type.SOUND)
    """
    The sound played when a pointed dripstone hits the surface.
    """
    POINTED_DRIPSTONE_DRIP_LAVA_INTO_CAULDRON = (1046, Type.SOUND)
    """
    The sound played when a pointed dripstone drips lava into a cauldron.
    """
    POINTED_DRIPSTONE_DRIP_WATER_INTO_CAULDRON = (1047, Type.SOUND)
    """
    The sound played when a pointed dripstone drips water into a cauldron.
    """
    SKELETON_CONVERTED_TO_STRAY = (1048, Type.SOUND)
    """
    The sound played when a skeleton converts to a stray.
    """
    COMPOSTER_FILL_ATTEMPT = (1500, Type.VISUAL, Boolean)
    """
    The sound played / particles shown when a composter is being attempted to
    fill.
    
    True for a successful attempt False for an unsuccessful attempt.
    """
    LAVA_INTERACT = (1501, Type.VISUAL)
    """
    The sound played / particles shown when lava interacts with the world.
    
    For example by forming stone, obsidian, basalt or destroying blocks such
    as torches.
    """
    REDSTONE_TORCH_BURNOUT = (1502, Type.VISUAL)
    """
    The sound played / particles shown when a redstone torch burns out.
    """
    END_PORTAL_FRAME_FILL = (1503, Type.VISUAL)
    """
    The sound played / particles shown when an eye of ender is placed into an
    ender portal frame.
    """
    DRIPPING_DRIPSTONE = (1504, Type.VISUAL)
    """
    The particles shown when a dripstone drips lava or water.
    
    This effect requires a dripstone at the location as well as lava or water
    at the root of the dripstone.
    """
    BONE_MEAL_USE = (1505, Type.VISUAL, Integer)
    """
    The sound played / particles shown when bone meal is used to grow a
    plant.
    
    Data is the number of particles.
    """
    ENDER_DRAGON_DESTROY_BLOCK = (2008, Type.VISUAL)
    """
    The particles shown when an ender dragon destroys blocks.
    """
    SPONGE_DRY = (2009, Type.VISUAL)
    """
    The particles shown when a sponge dries in an ultra warm world (nether).
    """
    ELECTRIC_SPARK = (3002, Type.VISUAL, Axis)
    """
    The particles shown when a lightning hits a lightning rod or oxidized
    copper.
    
    Data is the axis at which the particle should be shown. If no data is
    provided it will show the particles at the block faces.
    """
    COPPER_WAX_ON = (3003, Type.VISUAL)
    """
    The sound played / particles shown when wax is applied to a copper block.
    """
    COPPER_WAX_OFF = (3004, Type.VISUAL)
    """
    The particles shown when wax is removed from a copper block.
    """
    OXIDISED_COPPER_SCRAPE = (3005, Type.VISUAL)
    """
    The particles shown when oxidation is scraped of an oxidized copper
    block.
    """


    def getId(self) -> int:
        """
        Gets the ID for this effect.

        Returns
        - ID of this effect

        Deprecated
        - Magic value
        """
        ...


    def getType(self) -> "Type":
        """
        Returns
        - The type of the effect.
        """
        ...


    def getData(self) -> type[Any]:
        """
        Returns
        - The class which represents data for this effect, or null if
            none
        """
        ...


    @staticmethod
    def getById(id: int) -> "Effect":
        """
        Gets the Effect associated with the given ID.

        Arguments
        - id: ID of the Effect to return

        Returns
        - Effect with the given ID

        Deprecated
        - Magic value
        """
        ...


    class Type(Enum):
        """
        Represents the type of an effect.
        """

        SOUND = 0
        VISUAL = 1



"""
Python module generated from Java source file com.google.gson.internal.GsonBuildConfig

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from typing import Any, Callable, Iterable, Tuple


class GsonBuildConfig:
    """
    Build configuration for Gson. This file is automatically populated by templating-maven-plugin and
    .java/.class files are generated for use in Gson.

    Author(s)
    - Inderjeet Singh
    """

    VERSION = "2.11.0"
    """
    This field is automatically populated by Maven when a build is triggered
    """



"""
Python module generated from Java source file java.io.EOFException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class EOFException(IOException):
    """
    Signals that an end of file or end of stream has been reached
    unexpectedly during input.
    
    This exception is mainly used by data input streams to signal end of
    stream. Note that many other input operations return a special value on
    end of stream rather than throwing an exception.

    Author(s)
    - Frank Yellin

    See
    - java.io.IOException

    Since
    - 1.0
    """

    def __init__(self):
        """
        Constructs an `EOFException` with `null`
        as its error detail message.
        """
        ...


    def __init__(self, s: str):
        """
        Constructs an `EOFException` with the specified detail
        message. The string `s` may later be retrieved by the
        java.lang.Throwable.getMessage method of class
        `java.lang.Throwable`.

        Arguments
        - s: the detail message.
        """
        ...



"""
Python module generated from Java source file com.google.common.base.Joiner

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import IOException
from java.util import AbstractList
from java.util import Arrays
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Joiner:
    """
    An object which joins pieces of text (specified as an array, Iterable, varargs or even a
    Map) with a separator. It either appends the results to an Appendable or returns
    them as a String. Example:
    
    ````Joiner joiner = Joiner.on("; ").skipNulls();
     . . .
    return joiner.join("Harry", null, "Ron", "Hermione");````
    
    This returns the string `"Harry; Ron; Hermione"`. Note that all input elements are
    converted to strings using Object.toString() before being appended.
    
    If neither .skipNulls() nor .useForNull(String) is specified, the joining
    methods will throw NullPointerException if any given element is null.
    
    **Warning: joiner instances are always immutable**; a configuration method such as `useForNull` has no effect on the instance it is invoked on! You must store and use the new joiner
    instance returned by the method. This makes joiners thread-safe, and safe to store as `static final` constants.
    
    ````// Bad! Do not do this!
    Joiner joiner = Joiner.on(',');
    joiner.skipNulls(); // does nothing!
    return joiner.join("wrong", null, "wrong");````
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/StringsExplained#joiner">`Joiner`</a>.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    @staticmethod
    def on(separator: str) -> "Joiner":
        """
        Returns a joiner which automatically places `separator` between consecutive elements.
        """
        ...


    @staticmethod
    def on(separator: str) -> "Joiner":
        """
        Returns a joiner which automatically places `separator` between consecutive elements.
        """
        ...


    def appendTo(self, appendable: "A", parts: Iterable["Object"]) -> "A":
        """
        Appends the string representation of each of `parts`, using the previously configured
        separator between each, to `appendable`.
        """
        ...


    def appendTo(self, appendable: "A", parts: Iterator["Object"]) -> "A":
        """
        Appends the string representation of each of `parts`, using the previously configured
        separator between each, to `appendable`.

        Since
        - 11.0
        """
        ...


    def appendTo(self, appendable: "A", parts: list["Object"]) -> "A":
        """
        Appends the string representation of each of `parts`, using the previously configured
        separator between each, to `appendable`.
        """
        ...


    def appendTo(self, appendable: "A", first: "Object", second: "Object", *rest: Tuple["Object", ...]) -> "A":
        """
        Appends to `appendable` the string representation of each of the remaining arguments.
        """
        ...


    def appendTo(self, builder: "StringBuilder", parts: Iterable["Object"]) -> "StringBuilder":
        """
        Appends the string representation of each of `parts`, using the previously configured
        separator between each, to `builder`. Identical to .appendTo(Appendable,
        Iterable), except that it does not throw IOException.
        """
        ...


    def appendTo(self, builder: "StringBuilder", parts: Iterator["Object"]) -> "StringBuilder":
        """
        Appends the string representation of each of `parts`, using the previously configured
        separator between each, to `builder`. Identical to .appendTo(Appendable,
        Iterable), except that it does not throw IOException.

        Since
        - 11.0
        """
        ...


    def appendTo(self, builder: "StringBuilder", parts: list["Object"]) -> "StringBuilder":
        """
        Appends the string representation of each of `parts`, using the previously configured
        separator between each, to `builder`. Identical to .appendTo(Appendable,
        Iterable), except that it does not throw IOException.
        """
        ...


    def appendTo(self, builder: "StringBuilder", first: "Object", second: "Object", *rest: Tuple["Object", ...]) -> "StringBuilder":
        """
        Appends to `builder` the string representation of each of the remaining arguments.
        Identical to .appendTo(Appendable, Object, Object, Object...), except that it does not
        throw IOException.
        """
        ...


    def join(self, parts: Iterable["Object"]) -> str:
        """
        Returns a string containing the string representation of each of `parts`, using the
        previously configured separator between each.
        """
        ...


    def join(self, parts: Iterator["Object"]) -> str:
        """
        Returns a string containing the string representation of each of `parts`, using the
        previously configured separator between each.

        Since
        - 11.0
        """
        ...


    def join(self, parts: list["Object"]) -> str:
        """
        Returns a string containing the string representation of each of `parts`, using the
        previously configured separator between each.
        """
        ...


    def join(self, first: "Object", second: "Object", *rest: Tuple["Object", ...]) -> str:
        """
        Returns a string containing the string representation of each argument, using the previously
        configured separator between each.
        """
        ...


    def useForNull(self, nullText: str) -> "Joiner":
        """
        Returns a joiner with the same behavior as this one, except automatically substituting `nullText` for any provided null elements.
        """
        ...


    def skipNulls(self) -> "Joiner":
        """
        Returns a joiner with the same behavior as this joiner, except automatically skipping over any
        provided null elements.
        """
        ...


    def withKeyValueSeparator(self, keyValueSeparator: str) -> "MapJoiner":
        """
        Returns a `MapJoiner` using the given key-value separator, and the same configuration as
        this `Joiner` otherwise.

        Since
        - 20.0
        """
        ...


    def withKeyValueSeparator(self, keyValueSeparator: str) -> "MapJoiner":
        """
        Returns a `MapJoiner` using the given key-value separator, and the same configuration as
        this `Joiner` otherwise.
        """
        ...


    class MapJoiner:
        """
        An object that joins map entries in the same manner as `Joiner` joins iterables and
        arrays. Like `Joiner`, it is thread-safe and immutable.
        
        In addition to operating on `Map` instances, `MapJoiner` can operate on `Multimap` entries in two distinct modes:
        
        
          - To output a separate entry for each key-value pair, pass `multimap.entries()` to a
              `MapJoiner` method that accepts entries as input, and receive output of the form
              `key1=A&key1=B&key2=C`.
          - To output a single entry for each key, pass `multimap.asMap()` to a `MapJoiner` method that accepts a map as input, and receive output of the form `key1=[A, B]&key2=C`.

        Since
        - 2.0
        """

        def appendTo(self, appendable: "A", map: dict[Any, Any]) -> "A":
            """
            Appends the string representation of each entry of `map`, using the previously
            configured separator and key-value separator, to `appendable`.
            """
            ...


        def appendTo(self, builder: "StringBuilder", map: dict[Any, Any]) -> "StringBuilder":
            """
            Appends the string representation of each entry of `map`, using the previously
            configured separator and key-value separator, to `builder`. Identical to .appendTo(Appendable, Map), except that it does not throw IOException.
            """
            ...


        def appendTo(self, appendable: "A", entries: Iterable["Entry"[Any, Any]]) -> "A":
            """
            Appends the string representation of each entry in `entries`, using the previously
            configured separator and key-value separator, to `appendable`.

            Since
            - 10.0
            """
            ...


        def appendTo(self, appendable: "A", parts: Iterator["Entry"[Any, Any]]) -> "A":
            """
            Appends the string representation of each entry in `entries`, using the previously
            configured separator and key-value separator, to `appendable`.

            Since
            - 11.0
            """
            ...


        def appendTo(self, builder: "StringBuilder", entries: Iterable["Entry"[Any, Any]]) -> "StringBuilder":
            """
            Appends the string representation of each entry in `entries`, using the previously
            configured separator and key-value separator, to `builder`. Identical to .appendTo(Appendable, Iterable), except that it does not throw IOException.

            Since
            - 10.0
            """
            ...


        def appendTo(self, builder: "StringBuilder", entries: Iterator["Entry"[Any, Any]]) -> "StringBuilder":
            """
            Appends the string representation of each entry in `entries`, using the previously
            configured separator and key-value separator, to `builder`. Identical to .appendTo(Appendable, Iterable), except that it does not throw IOException.

            Since
            - 11.0
            """
            ...


        def join(self, map: dict[Any, Any]) -> str:
            """
            Returns a string containing the string representation of each entry of `map`, using the
            previously configured separator and key-value separator.
            """
            ...


        def join(self, entries: Iterable["Entry"[Any, Any]]) -> str:
            """
            Returns a string containing the string representation of each entry in `entries`, using
            the previously configured separator and key-value separator.

            Since
            - 10.0
            """
            ...


        def join(self, entries: Iterator["Entry"[Any, Any]]) -> str:
            """
            Returns a string containing the string representation of each entry in `entries`, using
            the previously configured separator and key-value separator.

            Since
            - 11.0
            """
            ...


        def useForNull(self, nullText: str) -> "MapJoiner":
            """
            Returns a map joiner with the same behavior as this one, except automatically substituting
            `nullText` for any provided null keys or values.
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.inventory.FurnaceSmeltEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event.block import BlockCookEvent
from org.bukkit.event.inventory import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class FurnaceSmeltEvent(BlockCookEvent):
    """
    Called when an ItemStack is successfully smelted in a furnace.
    """

    def __init__(self, furnace: "Block", source: "ItemStack", result: "ItemStack"):
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingMapEntry

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingMapEntry(ForwardingObject, Entry):
    """
    A map entry which forwards all its method calls to another map entry. Subclasses should override
    one or more methods to modify the behavior of the backing map entry as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingMapEntry` forward *indiscriminately* to
    the methods of the delegate. For example, overriding .getValue alone *will not*
    change the behavior of .equals, which can lead to unexpected behavior. In this case, you
    should override `equals` as well, either providing your own implementation, or delegating
    to the provided `standardEquals` method.
    
    Each of the `standard` methods, where appropriate, use Objects.equal to test
    equality for both keys and values. This may not be the desired behavior for map implementations
    that use non-standard notions of key equality, such as the entry of a `SortedMap` whose
    comparator is not consistent with `equals`.
    
    The `standard` methods are not guaranteed to be thread-safe, even when all of the
    methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    def getKey(self) -> "K":
        ...


    def getValue(self) -> "V":
        ...


    def setValue(self, value: "V") -> "V":
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file com.google.common.base.Predicate

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Predicate(Predicate):
    """
    Legacy version of java.util.function.Predicate java.util.function.Predicate. Determines a
    True or False value for a given input.
    
    As this interface extends `java.util.function.Predicate`, an instance of this type may
    be used as a `Predicate` directly. To use a `java.util.function.Predicate` where a
    `com.google.common.base.Predicate` is expected, use the method reference `predicate::test`.
    
    This interface is now a legacy type. Use `java.util.function.Predicate` (or the
    appropriate primitive specialization such as `IntPredicate`) instead whenever possible.
    Otherwise, at least reduce *explicit* dependencies on this type by using lambda expressions
    or method references instead of classes, leaving your code easier to migrate in the future.
    
    The Predicates class provides common predicates and related utilities.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/FunctionalExplained">the use of `Predicate`</a>.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    def apply(self, input: "T") -> bool:
        """
        Returns the result of applying this predicate to `input` (Java 8+ users, see notes in the
        class documentation above). This method is *generally expected*, but not absolutely
        required, to have the following properties:
        
        
          - Its execution does not cause any observable side effects.
          - The computation is *consistent with equals*; that is, Objects.equal
              Objects.equal`(a, b)` implies that `predicate.apply(a) ==
              predicate.apply(b))`.

        Raises
        - NullPointerException: if `input` is null and this predicate does not accept null
            arguments
        """
        ...


    def equals(self, object: "Object") -> bool:
        """
        Indicates whether another object is equal to this predicate.
        
        Most implementations will have no reason to override the behavior of Object.equals.
        However, an implementation may also choose to return `True` whenever `object` is a
        Predicate that it considers *interchangeable* with this one. "Interchangeable"
        *typically* means that `this.apply(t) == that.apply(t)` for all `t` of type
        `T`). Note that a `False` result from this method does not imply that the
        predicates are known *not* to be interchangeable.
        """
        ...


    def test(self, input: "T") -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerChangedMainHandEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import MainHand
from typing import Any, Callable, Iterable, Tuple


class PlayerChangedMainHandEvent(PlayerEvent):
    """
    Called when a player changes their main hand in the client settings.
    """

    def __init__(self, who: "Player", mainHand: "MainHand"):
        ...


    def getMainHand(self) -> "MainHand":
        """
        Gets the new main hand of the player. The old hand is still momentarily
        available via Player.getMainHand().

        Returns
        - the new MainHand of the player
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.scoreboard.ScoreboardManager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.ref import WeakReference
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class ScoreboardManager:
    """
    Manager of Scoreboards
    """

    def getMainScoreboard(self) -> "Scoreboard":
        """
        Gets the primary Scoreboard controlled by the server.
        
        This Scoreboard is saved by the server, is affected by the /scoreboard
        command, and is the scoreboard shown by default to players.

        Returns
        - the default server scoreboard
        """
        ...


    def getNewScoreboard(self) -> "Scoreboard":
        """
        Gets a new Scoreboard to be tracked by the server. This scoreboard will
        be tracked as long as a reference is kept, either by a player or by a
        plugin.

        Returns
        - the registered Scoreboard

        See
        - WeakReference
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Enderman

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import BlockData
from org.bukkit.entity import *
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class Enderman(Monster):
    """
    Represents an Enderman.
    """

    def getCarriedMaterial(self) -> "MaterialData":
        """
        Gets the id and data of the block that the Enderman is carrying.

        Returns
        - MaterialData containing the id and data of the block
        """
        ...


    def setCarriedMaterial(self, material: "MaterialData") -> None:
        """
        Sets the id and data of the block that the Enderman is carrying.

        Arguments
        - material: data to set the carried block to
        """
        ...


    def getCarriedBlock(self) -> "BlockData":
        """
        Gets the data of the block that the Enderman is carrying.

        Returns
        - BlockData containing the carried block, or null if none
        """
        ...


    def setCarriedBlock(self, blockData: "BlockData") -> None:
        """
        Sets the data of the block that the Enderman is carrying.

        Arguments
        - blockData: data to set the carried block to, or null to remove
        """
        ...


    def teleport(self) -> bool:
        """
        Randomly teleports the Enderman in a 64x64x64 block cuboid region.
        
        If the randomly selected point is in the ground, the point is moved 1 block
        down until air is found or until it goes under
        org.bukkit.World.getMinHeight().
        
        This method will return False if this Enderman is not alive, or if the
        teleport location was obstructed, or if the teleport location is in water.

        Returns
        - True if the teleport succeeded.
        """
        ...


    def teleportTowards(self, entity: "Entity") -> bool:
        """
        Randomly teleports the Enderman towards the given `entity`.
        
        The point is selected by drawing a vector between this enderman and the
        given `entity`. That vector's length is set to 16 blocks.
        That point is then moved within a 8x8x8 cuboid region. If the randomly
        selected point is in the ground, the point is moved 1 block down until
        air is found or until it goes under
        org.bukkit.World.getMinHeight().
        
        This method will return False if this Enderman is not alive, or if the
        teleport location was obstructed, or if the teleport location is in water.

        Arguments
        - entity: The entity to teleport towards.

        Returns
        - True if the teleport succeeded.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Shearable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Shearable:
    """
    Represents an entity which can be shorn with shears.
    """

    def isSheared(self) -> bool:
        """
        Gets whether the entity is in its sheared state.

        Returns
        - Whether the entity is sheared.
        """
        ...


    def setSheared(self, flag: bool) -> None:
        """
        Sets whether the entity is in its sheared state.

        Arguments
        - flag: Whether to shear the entity
        """
        ...



"""
Python module generated from Java source file org.bukkit.util.noise.PerlinNoiseGenerator

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Random
from org.bukkit import World
from org.bukkit.util.noise import *
from typing import Any, Callable, Iterable, Tuple


class PerlinNoiseGenerator(NoiseGenerator):
    """
    Generates noise using the "classic" perlin generator

    See
    - SimplexNoiseGenerator "Improved" and faster version with slightly
        different results
    """

    def __init__(self, world: "World"):
        """
        Creates a seeded perlin noise generator for the given world

        Arguments
        - world: World to construct this generator for
        """
        ...


    def __init__(self, seed: int):
        """
        Creates a seeded perlin noise generator for the given seed

        Arguments
        - seed: Seed to construct this generator for
        """
        ...


    def __init__(self, rand: "Random"):
        """
        Creates a seeded perlin noise generator with the given Random

        Arguments
        - rand: Random to construct with
        """
        ...


    @staticmethod
    def getNoise(x: float) -> float:
        """
        Computes and returns the 1D unseeded perlin noise for the given
        coordinates in 1D space

        Arguments
        - x: X coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getNoise(x: float, y: float) -> float:
        """
        Computes and returns the 2D unseeded perlin noise for the given
        coordinates in 2D space

        Arguments
        - x: X coordinate
        - y: Y coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getNoise(x: float, y: float, z: float) -> float:
        """
        Computes and returns the 3D unseeded perlin noise for the given
        coordinates in 3D space

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getInstance() -> "PerlinNoiseGenerator":
        """
        Gets the singleton unseeded instance of this generator

        Returns
        - Singleton
        """
        ...


    def noise(self, x: float, y: float, z: float) -> float:
        ...


    @staticmethod
    def getNoise(x: float, octaves: int, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 1D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    @staticmethod
    def getNoise(x: float, y: float, octaves: int, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 2D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    @staticmethod
    def getNoise(x: float, y: float, z: float, octaves: int, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.RecipeChoice

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Arrays
from java.util import Collections
from java.util import Objects
from java.util.function import Predicate
from org.bukkit import Bukkit
from org.bukkit import Material
from org.bukkit import Tag
from org.bukkit.inventory import *
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class RecipeChoice(Predicate, Cloneable):
    """
    Represents a potential item match within a recipe. All choices within a
    recipe must be satisfied for it to be craftable. Choices must never be
    null or air.
    
    **This class is not legal for implementation by plugins!**
    """

    def getItemStack(self) -> "ItemStack":
        """
        Gets a single item stack representative of this stack choice.

        Returns
        - a single representative item

        Deprecated
        - for compatibility only
        """
        ...


    def clone(self) -> "RecipeChoice":
        ...


    def test(self, itemStack: "ItemStack") -> bool:
        ...


    class MaterialChoice(RecipeChoice):
        """
        Represents a choice of multiple matching Materials.
        """

        def __init__(self, choice: "Material"):
            ...


        def __init__(self, *choices: Tuple["Material", ...]):
            ...


        def __init__(self, choices: "Tag"["Material"]):
            """
            Constructs a MaterialChoice with the current values of the specified
            tag.

            Arguments
            - choices: the tag
            """
            ...


        def __init__(self, choices: list["Material"]):
            ...


        def test(self, t: "ItemStack") -> bool:
            ...


        def getItemStack(self) -> "ItemStack":
            ...


        def getChoices(self) -> list["Material"]:
            ...


        def clone(self) -> "MaterialChoice":
            ...


        def hashCode(self) -> int:
            ...


        def equals(self, obj: "Object") -> bool:
            ...


        def toString(self) -> str:
            ...


    class ExactChoice(RecipeChoice):
        """
        Represents a choice that will be valid only if one of the stacks is
        exactly matched (aside from stack size).
        
        **Only valid for shaped recipes**
        """

        def __init__(self, stack: "ItemStack"):
            ...


        def __init__(self, *stacks: Tuple["ItemStack", ...]):
            ...


        def __init__(self, choices: list["ItemStack"]):
            ...


        def getItemStack(self) -> "ItemStack":
            ...


        def getChoices(self) -> list["ItemStack"]:
            ...


        def clone(self) -> "ExactChoice":
            ...


        def test(self, t: "ItemStack") -> bool:
            ...


        def hashCode(self) -> int:
            ...


        def equals(self, obj: "Object") -> bool:
            ...


        def toString(self) -> str:
            ...



"""
Python module generated from Java source file java.security.PrivilegedExceptionAction

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.security import *
from typing import Any, Callable, Iterable, Tuple


class PrivilegedExceptionAction:
    """
    A computation to be performed with privileges enabled, that throws one or
    more checked exceptions.  The computation is performed by invoking
    `AccessController.doPrivileged` on the
    `PrivilegedExceptionAction` object.  This interface is
    used only for computations that throw checked exceptions;
    computations that do not throw
    checked exceptions should use `PrivilegedAction` instead.

    See
    - PrivilegedAction

    Since
    - 1.2
    """

    def run(self) -> "T":
        ...



"""
Python module generated from Java source file com.google.gson.internal.PreJava9DateFormatProvider

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.text import DateFormat
from java.text import SimpleDateFormat
from java.util import Locale
from typing import Any, Callable, Iterable, Tuple


class PreJava9DateFormatProvider:
    """
    Provides DateFormats for US locale with patterns which were the default ones before Java 9.
    """

    @staticmethod
    def getUsDateTimeFormat(dateStyle: int, timeStyle: int) -> "DateFormat":
        """
        Returns the same DateFormat as `DateFormat.getDateTimeInstance(dateStyle, timeStyle,
        Locale.US)` in Java 8 or below.
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.SkullMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import NamespacedKey
from org.bukkit import OfflinePlayer
from org.bukkit.inventory.meta import *
from org.bukkit.profile import PlayerProfile
from typing import Any, Callable, Iterable, Tuple


class SkullMeta(ItemMeta):
    """
    Represents a skull that can have an owner.
    """

    def getOwner(self) -> str:
        """
        Gets the owner of the skull.

        Returns
        - the owner if the skull

        Deprecated
        - see .getOwningPlayer().
        """
        ...


    def hasOwner(self) -> bool:
        """
        Checks to see if the skull has an owner.

        Returns
        - True if the skull has an owner
        """
        ...


    def setOwner(self, owner: str) -> bool:
        """
        Sets the owner of the skull.

        Arguments
        - owner: the new owner of the skull

        Returns
        - True if the owner was successfully set

        Deprecated
        - see .setOwningPlayer(org.bukkit.OfflinePlayer).
        """
        ...


    def getOwningPlayer(self) -> "OfflinePlayer":
        """
        Gets the owner of the skull.

        Returns
        - the owner if the skull
        """
        ...


    def setOwningPlayer(self, owner: "OfflinePlayer") -> bool:
        """
        Sets the owner of the skull.
        
        Plugins should check that hasOwner() returns True before calling this
        plugin.

        Arguments
        - owner: the new owner of the skull

        Returns
        - True if the owner was successfully set
        """
        ...


    def getOwnerProfile(self) -> "PlayerProfile":
        """
        Gets the profile of the player who owns the skull. This player profile
        may appear as the texture depending on skull type.

        Returns
        - the profile of the owning player
        """
        ...


    def setOwnerProfile(self, profile: "PlayerProfile") -> None:
        """
        Sets the profile of the player who owns the skull. This player profile
        may appear as the texture depending on skull type.
        
        The profile must contain both a unique id and a skin texture. If either
        of these is missing, the profile must contain a name by which the server
        will then attempt to look up the unique id and skin texture.

        Arguments
        - profile: the profile of the owning player

        Raises
        - IllegalArgumentException: if the profile does not contain the
        necessary information
        """
        ...


    def setNoteBlockSound(self, noteBlockSound: "NamespacedKey") -> None:
        """
        Sets the sound to play if the skull is placed on a note block.
        
        <strong>Note:</strong> This only works for player heads. For other heads,
        see org.bukkit.Instrument.

        Arguments
        - noteBlockSound: the key of the sound to be played, or null
        """
        ...


    def getNoteBlockSound(self) -> "NamespacedKey":
        """
        Gets the sound to play if the skull is placed on a note block.
        
        <strong>Note:</strong> This only works for player heads. For other heads,
        see org.bukkit.Instrument.

        Returns
        - the key of the sound, or null
        """
        ...


    def clone(self) -> "SkullMeta":
        ...



"""
Python module generated from Java source file com.google.common.collect.Comparators

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import Comparator
from java.util import Iterator
from java.util import Optional
from java.util.stream import Collector
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Comparators:
    """
    Provides static methods for working with Comparator instances. For many other helpful
    comparator utilities, see either `Comparator` itself (for Java 8+), or `com.google.common.collect.Ordering` (otherwise).
    
    <h3>Relationship to `Ordering`</h3>
    
    In light of the significant enhancements to `Comparator` in Java 8, the overwhelming
    majority of usages of `Ordering` can be written using only built-in JDK APIs. This class is
    intended to "fill the gap" and provide those features of `Ordering` not already provided by
    the JDK.

    Author(s)
    - Louis Wasserman

    Since
    - 21.0
    """

    @staticmethod
    def lexicographical(comparator: "Comparator"["T"]) -> "Comparator"[Iterable["S"]]:
        ...


    @staticmethod
    def isInOrder(iterable: Iterable["T"], comparator: "Comparator"["T"]) -> bool:
        """
        Returns `True` if each element in `iterable` after the first is greater than or
        equal to the element that preceded it, according to the specified comparator. Note that this is
        always True when the iterable has fewer than two elements.
        """
        ...


    @staticmethod
    def isInStrictOrder(iterable: Iterable["T"], comparator: "Comparator"["T"]) -> bool:
        """
        Returns `True` if each element in `iterable` after the first is *strictly*
        greater than the element that preceded it, according to the specified comparator. Note that
        this is always True when the iterable has fewer than two elements.
        """
        ...


    @staticmethod
    def least(k: int, comparator: "Comparator"["T"]) -> "Collector"["T", Any, list["T"]]:
        """
        Returns a `Collector` that returns the `k` smallest (relative to the specified
        `Comparator`) input elements, in ascending order, as an unmodifiable `List`. Ties
        are broken arbitrarily.
        
        For example:
        
        ````Stream.of("foo", "quux", "banana", "elephant")
            .collect(least(2, comparingInt(String::length)))
        // returns {"foo", "quux"`
        }```
        
        This `Collector` uses O(k) memory and takes expected time O(n) (worst-case O(n log
        k)), as opposed to e.g. `Stream.sorted(comparator).limit(k)`, which currently takes O(n
        log n) time and O(n) space.

        Raises
        - IllegalArgumentException: if `k < 0`

        Since
        - 22.0
        """
        ...


    @staticmethod
    def greatest(k: int, comparator: "Comparator"["T"]) -> "Collector"["T", Any, list["T"]]:
        """
        Returns a `Collector` that returns the `k` greatest (relative to the specified
        `Comparator`) input elements, in descending order, as an unmodifiable `List`. Ties
        are broken arbitrarily.
        
        For example:
        
        ````Stream.of("foo", "quux", "banana", "elephant")
            .collect(greatest(2, comparingInt(String::length)))
        // returns {"elephant", "banana"`
        }```
        
        This `Collector` uses O(k) memory and takes expected time O(n) (worst-case O(n log
        k)), as opposed to e.g. `Stream.sorted(comparator.reversed()).limit(k)`, which currently
        takes O(n log n) time and O(n) space.

        Raises
        - IllegalArgumentException: if `k < 0`

        Since
        - 22.0
        """
        ...


    @staticmethod
    def emptiesFirst(valueComparator: "Comparator"["T"]) -> "Comparator"["Optional"["T"]]:
        """
        Returns a comparator of Optional values which treats Optional.empty as less
        than all other values, and orders the rest using `valueComparator` on the contained
        value.

        Since
        - 22.0
        """
        ...


    @staticmethod
    def emptiesLast(valueComparator: "Comparator"["T"]) -> "Comparator"["Optional"["T"]]:
        """
        Returns a comparator of Optional values which treats Optional.empty as greater
        than all other values, and orders the rest using `valueComparator` on the contained
        value.

        Since
        - 22.0
        """
        ...


    @staticmethod
    def min(a: "T", b: "T") -> "T":
        """
        Returns the minimum of the two values. If the values compare as 0, the first is returned.
        
        The recommended solution for finding the `minimum` of some values depends on the type
        of your data and the number of elements you have. Read more in the Guava User Guide article on
        <a href="https://github.com/google/guava/wiki/CollectionUtilitiesExplained#comparators">`Comparators`</a>.

        Arguments
        - a: first value to compare, returned if less than or equal to b.
        - b: second value to compare.

        Raises
        - ClassCastException: if the parameters are not *mutually comparable*.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def min(a: "T", b: "T", comparator: "Comparator"["T"]) -> "T":
        """
        Returns the minimum of the two values, according to the given comparator. If the values compare
        as equal, the first is returned.
        
        The recommended solution for finding the `minimum` of some values depends on the type
        of your data and the number of elements you have. Read more in the Guava User Guide article on
        <a href="https://github.com/google/guava/wiki/CollectionUtilitiesExplained#comparators">`Comparators`</a>.

        Arguments
        - a: first value to compare, returned if less than or equal to b
        - b: second value to compare.

        Raises
        - ClassCastException: if the parameters are not *mutually comparable* using the given
            comparator.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def max(a: "T", b: "T") -> "T":
        """
        Returns the maximum of the two values. If the values compare as 0, the first is returned.
        
        The recommended solution for finding the `maximum` of some values depends on the type
        of your data and the number of elements you have. Read more in the Guava User Guide article on
        <a href="https://github.com/google/guava/wiki/CollectionUtilitiesExplained#comparators">`Comparators`</a>.

        Arguments
        - a: first value to compare, returned if greater than or equal to b.
        - b: second value to compare.

        Raises
        - ClassCastException: if the parameters are not *mutually comparable*.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def max(a: "T", b: "T", comparator: "Comparator"["T"]) -> "T":
        """
        Returns the maximum of the two values, according to the given comparator. If the values compare
        as equal, the first is returned.
        
        The recommended solution for finding the `maximum` of some values depends on the type
        of your data and the number of elements you have. Read more in the Guava User Guide article on
        <a href="https://github.com/google/guava/wiki/CollectionUtilitiesExplained#comparators">`Comparators`</a>.

        Arguments
        - a: first value to compare, returned if greater than or equal to b.
        - b: second value to compare.

        Raises
        - ClassCastException: if the parameters are not *mutually comparable* using the given
            comparator.

        Since
        - 30.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.TropicalFish

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import DyeColor
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class TropicalFish(Fish):
    """
    Tropical fish.
    """

    def getPatternColor(self) -> "DyeColor":
        """
        Gets the color of the fish's pattern.

        Returns
        - pattern color
        """
        ...


    def setPatternColor(self, color: "DyeColor") -> None:
        """
        Sets the color of the fish's pattern

        Arguments
        - color: pattern color
        """
        ...


    def getBodyColor(self) -> "DyeColor":
        """
        Gets the color of the fish's body.

        Returns
        - pattern color
        """
        ...


    def setBodyColor(self, color: "DyeColor") -> None:
        """
        Sets the color of the fish's body

        Arguments
        - color: body color
        """
        ...


    def getPattern(self) -> "Pattern":
        """
        Gets the fish's pattern.

        Returns
        - pattern
        """
        ...


    def setPattern(self, pattern: "Pattern") -> None:
        """
        Sets the fish's pattern

        Arguments
        - pattern: new pattern
        """
        ...


    class Pattern(Enum):
        """
        Enumeration of all different fish patterns. Refer to the
        <a href="https://minecraft.wiki/w/Fish">Minecraft Wiki</a>
        for pictures.
        """

        KOB = 0
        SUNSTREAK = 1
        SNOOPER = 2
        DASHER = 3
        BRINELY = 4
        SPOTTY = 5
        FLOPPER = 6
        STRIPEY = 7
        GLITTER = 8
        BLOCKFISH = 9
        BETTY = 10
        CLAYFISH = 11
